
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "mm-enums-types.h"
/* enumerations from "../ModemManager/include/ModemManager-enums.h" */
static const GEnumValue mm_modem_lock_values[] = {
    { MM_MODEM_LOCK_UNKNOWN, "MM_MODEM_LOCK_UNKNOWN", "unknown" },
    { MM_MODEM_LOCK_NONE, "MM_MODEM_LOCK_NONE", "none" },
    { MM_MODEM_LOCK_SIM_PIN, "MM_MODEM_LOCK_SIM_PIN", "sim-pin" },
    { MM_MODEM_LOCK_SIM_PIN2, "MM_MODEM_LOCK_SIM_PIN2", "sim-pin2" },
    { MM_MODEM_LOCK_SIM_PUK, "MM_MODEM_LOCK_SIM_PUK", "sim-puk" },
    { MM_MODEM_LOCK_SIM_PUK2, "MM_MODEM_LOCK_SIM_PUK2", "sim-puk2" },
    { MM_MODEM_LOCK_PH_SP_PIN, "MM_MODEM_LOCK_PH_SP_PIN", "ph-sp-pin" },
    { MM_MODEM_LOCK_PH_SP_PUK, "MM_MODEM_LOCK_PH_SP_PUK", "ph-sp-puk" },
    { MM_MODEM_LOCK_PH_NET_PIN, "MM_MODEM_LOCK_PH_NET_PIN", "ph-net-pin" },
    { MM_MODEM_LOCK_PH_NET_PUK, "MM_MODEM_LOCK_PH_NET_PUK", "ph-net-puk" },
    { MM_MODEM_LOCK_PH_SIM_PIN, "MM_MODEM_LOCK_PH_SIM_PIN", "ph-sim-pin" },
    { MM_MODEM_LOCK_PH_CORP_PIN, "MM_MODEM_LOCK_PH_CORP_PIN", "ph-corp-pin" },
    { MM_MODEM_LOCK_PH_CORP_PUK, "MM_MODEM_LOCK_PH_CORP_PUK", "ph-corp-puk" },
    { MM_MODEM_LOCK_PH_FSIM_PIN, "MM_MODEM_LOCK_PH_FSIM_PIN", "ph-fsim-pin" },
    { MM_MODEM_LOCK_PH_FSIM_PUK, "MM_MODEM_LOCK_PH_FSIM_PUK", "ph-fsim-puk" },
    { MM_MODEM_LOCK_PH_NETSUB_PIN, "MM_MODEM_LOCK_PH_NETSUB_PIN", "ph-netsub-pin" },
    { MM_MODEM_LOCK_PH_NETSUB_PUK, "MM_MODEM_LOCK_PH_NETSUB_PUK", "ph-netsub-puk" },
    { 0, NULL, NULL }
};

GType
mm_modem_lock_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemLock"),
                                      mm_modem_lock_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_lock_get_string (MMModemLock val)
{
    guint i;

    for (i = 0; mm_modem_lock_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_lock_values[i].value)
            return mm_modem_lock_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_state_values[] = {
    { MM_MODEM_STATE_FAILED, "MM_MODEM_STATE_FAILED", "failed" },
    { MM_MODEM_STATE_UNKNOWN, "MM_MODEM_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_STATE_INITIALIZING, "MM_MODEM_STATE_INITIALIZING", "initializing" },
    { MM_MODEM_STATE_LOCKED, "MM_MODEM_STATE_LOCKED", "locked" },
    { MM_MODEM_STATE_DISABLED, "MM_MODEM_STATE_DISABLED", "disabled" },
    { MM_MODEM_STATE_DISABLING, "MM_MODEM_STATE_DISABLING", "disabling" },
    { MM_MODEM_STATE_ENABLING, "MM_MODEM_STATE_ENABLING", "enabling" },
    { MM_MODEM_STATE_ENABLED, "MM_MODEM_STATE_ENABLED", "enabled" },
    { MM_MODEM_STATE_SEARCHING, "MM_MODEM_STATE_SEARCHING", "searching" },
    { MM_MODEM_STATE_REGISTERED, "MM_MODEM_STATE_REGISTERED", "registered" },
    { MM_MODEM_STATE_DISCONNECTING, "MM_MODEM_STATE_DISCONNECTING", "disconnecting" },
    { MM_MODEM_STATE_CONNECTING, "MM_MODEM_STATE_CONNECTING", "connecting" },
    { MM_MODEM_STATE_CONNECTED, "MM_MODEM_STATE_CONNECTED", "connected" },
    { 0, NULL, NULL }
};

GType
mm_modem_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemState"),
                                      mm_modem_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_state_get_string (MMModemState val)
{
    guint i;

    for (i = 0; mm_modem_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_state_values[i].value)
            return mm_modem_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_state_failed_reason_values[] = {
    { MM_MODEM_STATE_FAILED_REASON_NONE, "MM_MODEM_STATE_FAILED_REASON_NONE", "none" },
    { MM_MODEM_STATE_FAILED_REASON_UNKNOWN, "MM_MODEM_STATE_FAILED_REASON_UNKNOWN", "unknown" },
    { MM_MODEM_STATE_FAILED_REASON_SIM_MISSING, "MM_MODEM_STATE_FAILED_REASON_SIM_MISSING", "sim-missing" },
    { MM_MODEM_STATE_FAILED_REASON_SIM_ERROR, "MM_MODEM_STATE_FAILED_REASON_SIM_ERROR", "sim-error" },
    { MM_MODEM_STATE_FAILED_REASON_UNKNOWN_CAPABILITIES, "MM_MODEM_STATE_FAILED_REASON_UNKNOWN_CAPABILITIES", "unknown-capabilities" },
    { MM_MODEM_STATE_FAILED_REASON_ESIM_WITHOUT_PROFILES, "MM_MODEM_STATE_FAILED_REASON_ESIM_WITHOUT_PROFILES", "esim-without-profiles" },
    { 0, NULL, NULL }
};

GType
mm_modem_state_failed_reason_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemStateFailedReason"),
                                      mm_modem_state_failed_reason_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_state_failed_reason_get_string (MMModemStateFailedReason val)
{
    guint i;

    for (i = 0; mm_modem_state_failed_reason_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_state_failed_reason_values[i].value)
            return mm_modem_state_failed_reason_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_power_state_values[] = {
    { MM_MODEM_POWER_STATE_UNKNOWN, "MM_MODEM_POWER_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_POWER_STATE_OFF, "MM_MODEM_POWER_STATE_OFF", "off" },
    { MM_MODEM_POWER_STATE_LOW, "MM_MODEM_POWER_STATE_LOW", "low" },
    { MM_MODEM_POWER_STATE_ON, "MM_MODEM_POWER_STATE_ON", "on" },
    { 0, NULL, NULL }
};

GType
mm_modem_power_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemPowerState"),
                                      mm_modem_power_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_power_state_get_string (MMModemPowerState val)
{
    guint i;

    for (i = 0; mm_modem_power_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_power_state_values[i].value)
            return mm_modem_power_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_state_change_reason_values[] = {
    { MM_MODEM_STATE_CHANGE_REASON_UNKNOWN, "MM_MODEM_STATE_CHANGE_REASON_UNKNOWN", "unknown" },
    { MM_MODEM_STATE_CHANGE_REASON_USER_REQUESTED, "MM_MODEM_STATE_CHANGE_REASON_USER_REQUESTED", "user-requested" },
    { MM_MODEM_STATE_CHANGE_REASON_SUSPEND, "MM_MODEM_STATE_CHANGE_REASON_SUSPEND", "suspend" },
    { MM_MODEM_STATE_CHANGE_REASON_FAILURE, "MM_MODEM_STATE_CHANGE_REASON_FAILURE", "failure" },
    { 0, NULL, NULL }
};

GType
mm_modem_state_change_reason_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemStateChangeReason"),
                                      mm_modem_state_change_reason_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_state_change_reason_get_string (MMModemStateChangeReason val)
{
    guint i;

    for (i = 0; mm_modem_state_change_reason_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_state_change_reason_values[i].value)
            return mm_modem_state_change_reason_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_band_values[] = {
    { MM_MODEM_BAND_UNKNOWN, "MM_MODEM_BAND_UNKNOWN", "unknown" },
    { MM_MODEM_BAND_EGSM, "MM_MODEM_BAND_EGSM", "egsm" },
    { MM_MODEM_BAND_DCS, "MM_MODEM_BAND_DCS", "dcs" },
    { MM_MODEM_BAND_PCS, "MM_MODEM_BAND_PCS", "pcs" },
    { MM_MODEM_BAND_G850, "MM_MODEM_BAND_G850", "g850" },
    { MM_MODEM_BAND_UTRAN_1, "MM_MODEM_BAND_UTRAN_1", "utran-1" },
    { MM_MODEM_BAND_UTRAN_3, "MM_MODEM_BAND_UTRAN_3", "utran-3" },
    { MM_MODEM_BAND_UTRAN_4, "MM_MODEM_BAND_UTRAN_4", "utran-4" },
    { MM_MODEM_BAND_UTRAN_6, "MM_MODEM_BAND_UTRAN_6", "utran-6" },
    { MM_MODEM_BAND_UTRAN_5, "MM_MODEM_BAND_UTRAN_5", "utran-5" },
    { MM_MODEM_BAND_UTRAN_8, "MM_MODEM_BAND_UTRAN_8", "utran-8" },
    { MM_MODEM_BAND_UTRAN_9, "MM_MODEM_BAND_UTRAN_9", "utran-9" },
    { MM_MODEM_BAND_UTRAN_2, "MM_MODEM_BAND_UTRAN_2", "utran-2" },
    { MM_MODEM_BAND_UTRAN_7, "MM_MODEM_BAND_UTRAN_7", "utran-7" },
    { MM_MODEM_BAND_G450, "MM_MODEM_BAND_G450", "g450" },
    { MM_MODEM_BAND_G480, "MM_MODEM_BAND_G480", "g480" },
    { MM_MODEM_BAND_G750, "MM_MODEM_BAND_G750", "g750" },
    { MM_MODEM_BAND_G380, "MM_MODEM_BAND_G380", "g380" },
    { MM_MODEM_BAND_G410, "MM_MODEM_BAND_G410", "g410" },
    { MM_MODEM_BAND_G710, "MM_MODEM_BAND_G710", "g710" },
    { MM_MODEM_BAND_G810, "MM_MODEM_BAND_G810", "g810" },
    { MM_MODEM_BAND_EUTRAN_1, "MM_MODEM_BAND_EUTRAN_1", "eutran-1" },
    { MM_MODEM_BAND_EUTRAN_2, "MM_MODEM_BAND_EUTRAN_2", "eutran-2" },
    { MM_MODEM_BAND_EUTRAN_3, "MM_MODEM_BAND_EUTRAN_3", "eutran-3" },
    { MM_MODEM_BAND_EUTRAN_4, "MM_MODEM_BAND_EUTRAN_4", "eutran-4" },
    { MM_MODEM_BAND_EUTRAN_5, "MM_MODEM_BAND_EUTRAN_5", "eutran-5" },
    { MM_MODEM_BAND_EUTRAN_6, "MM_MODEM_BAND_EUTRAN_6", "eutran-6" },
    { MM_MODEM_BAND_EUTRAN_7, "MM_MODEM_BAND_EUTRAN_7", "eutran-7" },
    { MM_MODEM_BAND_EUTRAN_8, "MM_MODEM_BAND_EUTRAN_8", "eutran-8" },
    { MM_MODEM_BAND_EUTRAN_9, "MM_MODEM_BAND_EUTRAN_9", "eutran-9" },
    { MM_MODEM_BAND_EUTRAN_10, "MM_MODEM_BAND_EUTRAN_10", "eutran-10" },
    { MM_MODEM_BAND_EUTRAN_11, "MM_MODEM_BAND_EUTRAN_11", "eutran-11" },
    { MM_MODEM_BAND_EUTRAN_12, "MM_MODEM_BAND_EUTRAN_12", "eutran-12" },
    { MM_MODEM_BAND_EUTRAN_13, "MM_MODEM_BAND_EUTRAN_13", "eutran-13" },
    { MM_MODEM_BAND_EUTRAN_14, "MM_MODEM_BAND_EUTRAN_14", "eutran-14" },
    { MM_MODEM_BAND_EUTRAN_17, "MM_MODEM_BAND_EUTRAN_17", "eutran-17" },
    { MM_MODEM_BAND_EUTRAN_18, "MM_MODEM_BAND_EUTRAN_18", "eutran-18" },
    { MM_MODEM_BAND_EUTRAN_19, "MM_MODEM_BAND_EUTRAN_19", "eutran-19" },
    { MM_MODEM_BAND_EUTRAN_20, "MM_MODEM_BAND_EUTRAN_20", "eutran-20" },
    { MM_MODEM_BAND_EUTRAN_21, "MM_MODEM_BAND_EUTRAN_21", "eutran-21" },
    { MM_MODEM_BAND_EUTRAN_22, "MM_MODEM_BAND_EUTRAN_22", "eutran-22" },
    { MM_MODEM_BAND_EUTRAN_23, "MM_MODEM_BAND_EUTRAN_23", "eutran-23" },
    { MM_MODEM_BAND_EUTRAN_24, "MM_MODEM_BAND_EUTRAN_24", "eutran-24" },
    { MM_MODEM_BAND_EUTRAN_25, "MM_MODEM_BAND_EUTRAN_25", "eutran-25" },
    { MM_MODEM_BAND_EUTRAN_26, "MM_MODEM_BAND_EUTRAN_26", "eutran-26" },
    { MM_MODEM_BAND_EUTRAN_27, "MM_MODEM_BAND_EUTRAN_27", "eutran-27" },
    { MM_MODEM_BAND_EUTRAN_28, "MM_MODEM_BAND_EUTRAN_28", "eutran-28" },
    { MM_MODEM_BAND_EUTRAN_29, "MM_MODEM_BAND_EUTRAN_29", "eutran-29" },
    { MM_MODEM_BAND_EUTRAN_30, "MM_MODEM_BAND_EUTRAN_30", "eutran-30" },
    { MM_MODEM_BAND_EUTRAN_31, "MM_MODEM_BAND_EUTRAN_31", "eutran-31" },
    { MM_MODEM_BAND_EUTRAN_32, "MM_MODEM_BAND_EUTRAN_32", "eutran-32" },
    { MM_MODEM_BAND_EUTRAN_33, "MM_MODEM_BAND_EUTRAN_33", "eutran-33" },
    { MM_MODEM_BAND_EUTRAN_34, "MM_MODEM_BAND_EUTRAN_34", "eutran-34" },
    { MM_MODEM_BAND_EUTRAN_35, "MM_MODEM_BAND_EUTRAN_35", "eutran-35" },
    { MM_MODEM_BAND_EUTRAN_36, "MM_MODEM_BAND_EUTRAN_36", "eutran-36" },
    { MM_MODEM_BAND_EUTRAN_37, "MM_MODEM_BAND_EUTRAN_37", "eutran-37" },
    { MM_MODEM_BAND_EUTRAN_38, "MM_MODEM_BAND_EUTRAN_38", "eutran-38" },
    { MM_MODEM_BAND_EUTRAN_39, "MM_MODEM_BAND_EUTRAN_39", "eutran-39" },
    { MM_MODEM_BAND_EUTRAN_40, "MM_MODEM_BAND_EUTRAN_40", "eutran-40" },
    { MM_MODEM_BAND_EUTRAN_41, "MM_MODEM_BAND_EUTRAN_41", "eutran-41" },
    { MM_MODEM_BAND_EUTRAN_42, "MM_MODEM_BAND_EUTRAN_42", "eutran-42" },
    { MM_MODEM_BAND_EUTRAN_43, "MM_MODEM_BAND_EUTRAN_43", "eutran-43" },
    { MM_MODEM_BAND_EUTRAN_44, "MM_MODEM_BAND_EUTRAN_44", "eutran-44" },
    { MM_MODEM_BAND_EUTRAN_45, "MM_MODEM_BAND_EUTRAN_45", "eutran-45" },
    { MM_MODEM_BAND_EUTRAN_46, "MM_MODEM_BAND_EUTRAN_46", "eutran-46" },
    { MM_MODEM_BAND_EUTRAN_47, "MM_MODEM_BAND_EUTRAN_47", "eutran-47" },
    { MM_MODEM_BAND_EUTRAN_48, "MM_MODEM_BAND_EUTRAN_48", "eutran-48" },
    { MM_MODEM_BAND_EUTRAN_49, "MM_MODEM_BAND_EUTRAN_49", "eutran-49" },
    { MM_MODEM_BAND_EUTRAN_50, "MM_MODEM_BAND_EUTRAN_50", "eutran-50" },
    { MM_MODEM_BAND_EUTRAN_51, "MM_MODEM_BAND_EUTRAN_51", "eutran-51" },
    { MM_MODEM_BAND_EUTRAN_52, "MM_MODEM_BAND_EUTRAN_52", "eutran-52" },
    { MM_MODEM_BAND_EUTRAN_53, "MM_MODEM_BAND_EUTRAN_53", "eutran-53" },
    { MM_MODEM_BAND_EUTRAN_54, "MM_MODEM_BAND_EUTRAN_54", "eutran-54" },
    { MM_MODEM_BAND_EUTRAN_55, "MM_MODEM_BAND_EUTRAN_55", "eutran-55" },
    { MM_MODEM_BAND_EUTRAN_56, "MM_MODEM_BAND_EUTRAN_56", "eutran-56" },
    { MM_MODEM_BAND_EUTRAN_57, "MM_MODEM_BAND_EUTRAN_57", "eutran-57" },
    { MM_MODEM_BAND_EUTRAN_58, "MM_MODEM_BAND_EUTRAN_58", "eutran-58" },
    { MM_MODEM_BAND_EUTRAN_59, "MM_MODEM_BAND_EUTRAN_59", "eutran-59" },
    { MM_MODEM_BAND_EUTRAN_60, "MM_MODEM_BAND_EUTRAN_60", "eutran-60" },
    { MM_MODEM_BAND_EUTRAN_61, "MM_MODEM_BAND_EUTRAN_61", "eutran-61" },
    { MM_MODEM_BAND_EUTRAN_62, "MM_MODEM_BAND_EUTRAN_62", "eutran-62" },
    { MM_MODEM_BAND_EUTRAN_63, "MM_MODEM_BAND_EUTRAN_63", "eutran-63" },
    { MM_MODEM_BAND_EUTRAN_64, "MM_MODEM_BAND_EUTRAN_64", "eutran-64" },
    { MM_MODEM_BAND_EUTRAN_65, "MM_MODEM_BAND_EUTRAN_65", "eutran-65" },
    { MM_MODEM_BAND_EUTRAN_66, "MM_MODEM_BAND_EUTRAN_66", "eutran-66" },
    { MM_MODEM_BAND_EUTRAN_67, "MM_MODEM_BAND_EUTRAN_67", "eutran-67" },
    { MM_MODEM_BAND_EUTRAN_68, "MM_MODEM_BAND_EUTRAN_68", "eutran-68" },
    { MM_MODEM_BAND_EUTRAN_69, "MM_MODEM_BAND_EUTRAN_69", "eutran-69" },
    { MM_MODEM_BAND_EUTRAN_70, "MM_MODEM_BAND_EUTRAN_70", "eutran-70" },
    { MM_MODEM_BAND_EUTRAN_71, "MM_MODEM_BAND_EUTRAN_71", "eutran-71" },
    { MM_MODEM_BAND_EUTRAN_85, "MM_MODEM_BAND_EUTRAN_85", "eutran-85" },
    { MM_MODEM_BAND_CDMA_BC0, "MM_MODEM_BAND_CDMA_BC0", "cdma-bc0" },
    { MM_MODEM_BAND_CDMA_BC1, "MM_MODEM_BAND_CDMA_BC1", "cdma-bc1" },
    { MM_MODEM_BAND_CDMA_BC2, "MM_MODEM_BAND_CDMA_BC2", "cdma-bc2" },
    { MM_MODEM_BAND_CDMA_BC3, "MM_MODEM_BAND_CDMA_BC3", "cdma-bc3" },
    { MM_MODEM_BAND_CDMA_BC4, "MM_MODEM_BAND_CDMA_BC4", "cdma-bc4" },
    { MM_MODEM_BAND_CDMA_BC5, "MM_MODEM_BAND_CDMA_BC5", "cdma-bc5" },
    { MM_MODEM_BAND_CDMA_BC6, "MM_MODEM_BAND_CDMA_BC6", "cdma-bc6" },
    { MM_MODEM_BAND_CDMA_BC7, "MM_MODEM_BAND_CDMA_BC7", "cdma-bc7" },
    { MM_MODEM_BAND_CDMA_BC8, "MM_MODEM_BAND_CDMA_BC8", "cdma-bc8" },
    { MM_MODEM_BAND_CDMA_BC9, "MM_MODEM_BAND_CDMA_BC9", "cdma-bc9" },
    { MM_MODEM_BAND_CDMA_BC10, "MM_MODEM_BAND_CDMA_BC10", "cdma-bc10" },
    { MM_MODEM_BAND_CDMA_BC11, "MM_MODEM_BAND_CDMA_BC11", "cdma-bc11" },
    { MM_MODEM_BAND_CDMA_BC12, "MM_MODEM_BAND_CDMA_BC12", "cdma-bc12" },
    { MM_MODEM_BAND_CDMA_BC13, "MM_MODEM_BAND_CDMA_BC13", "cdma-bc13" },
    { MM_MODEM_BAND_CDMA_BC14, "MM_MODEM_BAND_CDMA_BC14", "cdma-bc14" },
    { MM_MODEM_BAND_CDMA_BC15, "MM_MODEM_BAND_CDMA_BC15", "cdma-bc15" },
    { MM_MODEM_BAND_CDMA_BC16, "MM_MODEM_BAND_CDMA_BC16", "cdma-bc16" },
    { MM_MODEM_BAND_CDMA_BC17, "MM_MODEM_BAND_CDMA_BC17", "cdma-bc17" },
    { MM_MODEM_BAND_CDMA_BC18, "MM_MODEM_BAND_CDMA_BC18", "cdma-bc18" },
    { MM_MODEM_BAND_CDMA_BC19, "MM_MODEM_BAND_CDMA_BC19", "cdma-bc19" },
    { MM_MODEM_BAND_UTRAN_10, "MM_MODEM_BAND_UTRAN_10", "utran-10" },
    { MM_MODEM_BAND_UTRAN_11, "MM_MODEM_BAND_UTRAN_11", "utran-11" },
    { MM_MODEM_BAND_UTRAN_12, "MM_MODEM_BAND_UTRAN_12", "utran-12" },
    { MM_MODEM_BAND_UTRAN_13, "MM_MODEM_BAND_UTRAN_13", "utran-13" },
    { MM_MODEM_BAND_UTRAN_14, "MM_MODEM_BAND_UTRAN_14", "utran-14" },
    { MM_MODEM_BAND_UTRAN_19, "MM_MODEM_BAND_UTRAN_19", "utran-19" },
    { MM_MODEM_BAND_UTRAN_20, "MM_MODEM_BAND_UTRAN_20", "utran-20" },
    { MM_MODEM_BAND_UTRAN_21, "MM_MODEM_BAND_UTRAN_21", "utran-21" },
    { MM_MODEM_BAND_UTRAN_22, "MM_MODEM_BAND_UTRAN_22", "utran-22" },
    { MM_MODEM_BAND_UTRAN_25, "MM_MODEM_BAND_UTRAN_25", "utran-25" },
    { MM_MODEM_BAND_UTRAN_26, "MM_MODEM_BAND_UTRAN_26", "utran-26" },
    { MM_MODEM_BAND_UTRAN_32, "MM_MODEM_BAND_UTRAN_32", "utran-32" },
    { MM_MODEM_BAND_ANY, "MM_MODEM_BAND_ANY", "any" },
    { MM_MODEM_BAND_NGRAN_1, "MM_MODEM_BAND_NGRAN_1", "ngran-1" },
    { MM_MODEM_BAND_NGRAN_2, "MM_MODEM_BAND_NGRAN_2", "ngran-2" },
    { MM_MODEM_BAND_NGRAN_3, "MM_MODEM_BAND_NGRAN_3", "ngran-3" },
    { MM_MODEM_BAND_NGRAN_5, "MM_MODEM_BAND_NGRAN_5", "ngran-5" },
    { MM_MODEM_BAND_NGRAN_7, "MM_MODEM_BAND_NGRAN_7", "ngran-7" },
    { MM_MODEM_BAND_NGRAN_8, "MM_MODEM_BAND_NGRAN_8", "ngran-8" },
    { MM_MODEM_BAND_NGRAN_12, "MM_MODEM_BAND_NGRAN_12", "ngran-12" },
    { MM_MODEM_BAND_NGRAN_13, "MM_MODEM_BAND_NGRAN_13", "ngran-13" },
    { MM_MODEM_BAND_NGRAN_14, "MM_MODEM_BAND_NGRAN_14", "ngran-14" },
    { MM_MODEM_BAND_NGRAN_18, "MM_MODEM_BAND_NGRAN_18", "ngran-18" },
    { MM_MODEM_BAND_NGRAN_20, "MM_MODEM_BAND_NGRAN_20", "ngran-20" },
    { MM_MODEM_BAND_NGRAN_25, "MM_MODEM_BAND_NGRAN_25", "ngran-25" },
    { MM_MODEM_BAND_NGRAN_26, "MM_MODEM_BAND_NGRAN_26", "ngran-26" },
    { MM_MODEM_BAND_NGRAN_28, "MM_MODEM_BAND_NGRAN_28", "ngran-28" },
    { MM_MODEM_BAND_NGRAN_29, "MM_MODEM_BAND_NGRAN_29", "ngran-29" },
    { MM_MODEM_BAND_NGRAN_30, "MM_MODEM_BAND_NGRAN_30", "ngran-30" },
    { MM_MODEM_BAND_NGRAN_34, "MM_MODEM_BAND_NGRAN_34", "ngran-34" },
    { MM_MODEM_BAND_NGRAN_38, "MM_MODEM_BAND_NGRAN_38", "ngran-38" },
    { MM_MODEM_BAND_NGRAN_39, "MM_MODEM_BAND_NGRAN_39", "ngran-39" },
    { MM_MODEM_BAND_NGRAN_40, "MM_MODEM_BAND_NGRAN_40", "ngran-40" },
    { MM_MODEM_BAND_NGRAN_41, "MM_MODEM_BAND_NGRAN_41", "ngran-41" },
    { MM_MODEM_BAND_NGRAN_48, "MM_MODEM_BAND_NGRAN_48", "ngran-48" },
    { MM_MODEM_BAND_NGRAN_50, "MM_MODEM_BAND_NGRAN_50", "ngran-50" },
    { MM_MODEM_BAND_NGRAN_51, "MM_MODEM_BAND_NGRAN_51", "ngran-51" },
    { MM_MODEM_BAND_NGRAN_53, "MM_MODEM_BAND_NGRAN_53", "ngran-53" },
    { MM_MODEM_BAND_NGRAN_65, "MM_MODEM_BAND_NGRAN_65", "ngran-65" },
    { MM_MODEM_BAND_NGRAN_66, "MM_MODEM_BAND_NGRAN_66", "ngran-66" },
    { MM_MODEM_BAND_NGRAN_67, "MM_MODEM_BAND_NGRAN_67", "ngran-67" },
    { MM_MODEM_BAND_NGRAN_70, "MM_MODEM_BAND_NGRAN_70", "ngran-70" },
    { MM_MODEM_BAND_NGRAN_71, "MM_MODEM_BAND_NGRAN_71", "ngran-71" },
    { MM_MODEM_BAND_NGRAN_74, "MM_MODEM_BAND_NGRAN_74", "ngran-74" },
    { MM_MODEM_BAND_NGRAN_75, "MM_MODEM_BAND_NGRAN_75", "ngran-75" },
    { MM_MODEM_BAND_NGRAN_76, "MM_MODEM_BAND_NGRAN_76", "ngran-76" },
    { MM_MODEM_BAND_NGRAN_77, "MM_MODEM_BAND_NGRAN_77", "ngran-77" },
    { MM_MODEM_BAND_NGRAN_78, "MM_MODEM_BAND_NGRAN_78", "ngran-78" },
    { MM_MODEM_BAND_NGRAN_79, "MM_MODEM_BAND_NGRAN_79", "ngran-79" },
    { MM_MODEM_BAND_NGRAN_80, "MM_MODEM_BAND_NGRAN_80", "ngran-80" },
    { MM_MODEM_BAND_NGRAN_81, "MM_MODEM_BAND_NGRAN_81", "ngran-81" },
    { MM_MODEM_BAND_NGRAN_82, "MM_MODEM_BAND_NGRAN_82", "ngran-82" },
    { MM_MODEM_BAND_NGRAN_83, "MM_MODEM_BAND_NGRAN_83", "ngran-83" },
    { MM_MODEM_BAND_NGRAN_84, "MM_MODEM_BAND_NGRAN_84", "ngran-84" },
    { MM_MODEM_BAND_NGRAN_86, "MM_MODEM_BAND_NGRAN_86", "ngran-86" },
    { MM_MODEM_BAND_NGRAN_89, "MM_MODEM_BAND_NGRAN_89", "ngran-89" },
    { MM_MODEM_BAND_NGRAN_90, "MM_MODEM_BAND_NGRAN_90", "ngran-90" },
    { MM_MODEM_BAND_NGRAN_91, "MM_MODEM_BAND_NGRAN_91", "ngran-91" },
    { MM_MODEM_BAND_NGRAN_92, "MM_MODEM_BAND_NGRAN_92", "ngran-92" },
    { MM_MODEM_BAND_NGRAN_93, "MM_MODEM_BAND_NGRAN_93", "ngran-93" },
    { MM_MODEM_BAND_NGRAN_94, "MM_MODEM_BAND_NGRAN_94", "ngran-94" },
    { MM_MODEM_BAND_NGRAN_95, "MM_MODEM_BAND_NGRAN_95", "ngran-95" },
    { MM_MODEM_BAND_NGRAN_257, "MM_MODEM_BAND_NGRAN_257", "ngran-257" },
    { MM_MODEM_BAND_NGRAN_258, "MM_MODEM_BAND_NGRAN_258", "ngran-258" },
    { MM_MODEM_BAND_NGRAN_260, "MM_MODEM_BAND_NGRAN_260", "ngran-260" },
    { MM_MODEM_BAND_NGRAN_261, "MM_MODEM_BAND_NGRAN_261", "ngran-261" },
    { 0, NULL, NULL }
};

GType
mm_modem_band_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemBand"),
                                      mm_modem_band_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_band_get_string (MMModemBand val)
{
    guint i;

    for (i = 0; mm_modem_band_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_band_values[i].value)
            return mm_modem_band_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_port_type_values[] = {
    { MM_MODEM_PORT_TYPE_UNKNOWN, "MM_MODEM_PORT_TYPE_UNKNOWN", "unknown" },
    { MM_MODEM_PORT_TYPE_NET, "MM_MODEM_PORT_TYPE_NET", "net" },
    { MM_MODEM_PORT_TYPE_AT, "MM_MODEM_PORT_TYPE_AT", "at" },
    { MM_MODEM_PORT_TYPE_QCDM, "MM_MODEM_PORT_TYPE_QCDM", "qcdm" },
    { MM_MODEM_PORT_TYPE_GPS, "MM_MODEM_PORT_TYPE_GPS", "gps" },
    { MM_MODEM_PORT_TYPE_QMI, "MM_MODEM_PORT_TYPE_QMI", "qmi" },
    { MM_MODEM_PORT_TYPE_MBIM, "MM_MODEM_PORT_TYPE_MBIM", "mbim" },
    { MM_MODEM_PORT_TYPE_AUDIO, "MM_MODEM_PORT_TYPE_AUDIO", "audio" },
    { MM_MODEM_PORT_TYPE_IGNORED, "MM_MODEM_PORT_TYPE_IGNORED", "ignored" },
    { MM_MODEM_PORT_TYPE_XMMRPC, "MM_MODEM_PORT_TYPE_XMMRPC", "xmmrpc" },
    { 0, NULL, NULL }
};

GType
mm_modem_port_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemPortType"),
                                      mm_modem_port_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_port_type_get_string (MMModemPortType val)
{
    guint i;

    for (i = 0; mm_modem_port_type_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_port_type_values[i].value)
            return mm_modem_port_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_cell_type_values[] = {
    { MM_CELL_TYPE_UNKNOWN, "MM_CELL_TYPE_UNKNOWN", "unknown" },
    { MM_CELL_TYPE_CDMA, "MM_CELL_TYPE_CDMA", "cdma" },
    { MM_CELL_TYPE_GSM, "MM_CELL_TYPE_GSM", "gsm" },
    { MM_CELL_TYPE_UMTS, "MM_CELL_TYPE_UMTS", "umts" },
    { MM_CELL_TYPE_TDSCDMA, "MM_CELL_TYPE_TDSCDMA", "tdscdma" },
    { MM_CELL_TYPE_LTE, "MM_CELL_TYPE_LTE", "lte" },
    { MM_CELL_TYPE_5GNR, "MM_CELL_TYPE_5GNR", "5gnr" },
    { 0, NULL, NULL }
};

GType
mm_cell_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMCellType"),
                                      mm_cell_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_cell_type_get_string (MMCellType val)
{
    guint i;

    for (i = 0; mm_cell_type_values[i].value_nick; i++) {
        if ((gint)val == mm_cell_type_values[i].value)
            return mm_cell_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sms_pdu_type_values[] = {
    { MM_SMS_PDU_TYPE_UNKNOWN, "MM_SMS_PDU_TYPE_UNKNOWN", "unknown" },
    { MM_SMS_PDU_TYPE_DELIVER, "MM_SMS_PDU_TYPE_DELIVER", "deliver" },
    { MM_SMS_PDU_TYPE_SUBMIT, "MM_SMS_PDU_TYPE_SUBMIT", "submit" },
    { MM_SMS_PDU_TYPE_STATUS_REPORT, "MM_SMS_PDU_TYPE_STATUS_REPORT", "status-report" },
    { MM_SMS_PDU_TYPE_CDMA_DELIVER, "MM_SMS_PDU_TYPE_CDMA_DELIVER", "cdma-deliver" },
    { MM_SMS_PDU_TYPE_CDMA_SUBMIT, "MM_SMS_PDU_TYPE_CDMA_SUBMIT", "cdma-submit" },
    { MM_SMS_PDU_TYPE_CDMA_CANCELLATION, "MM_SMS_PDU_TYPE_CDMA_CANCELLATION", "cdma-cancellation" },
    { MM_SMS_PDU_TYPE_CDMA_DELIVERY_ACKNOWLEDGEMENT, "MM_SMS_PDU_TYPE_CDMA_DELIVERY_ACKNOWLEDGEMENT", "cdma-delivery-acknowledgement" },
    { MM_SMS_PDU_TYPE_CDMA_USER_ACKNOWLEDGEMENT, "MM_SMS_PDU_TYPE_CDMA_USER_ACKNOWLEDGEMENT", "cdma-user-acknowledgement" },
    { MM_SMS_PDU_TYPE_CDMA_READ_ACKNOWLEDGEMENT, "MM_SMS_PDU_TYPE_CDMA_READ_ACKNOWLEDGEMENT", "cdma-read-acknowledgement" },
    { 0, NULL, NULL }
};

GType
mm_sms_pdu_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSmsPduType"),
                                      mm_sms_pdu_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sms_pdu_type_get_string (MMSmsPduType val)
{
    guint i;

    for (i = 0; mm_sms_pdu_type_values[i].value_nick; i++) {
        if ((gint)val == mm_sms_pdu_type_values[i].value)
            return mm_sms_pdu_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sms_state_values[] = {
    { MM_SMS_STATE_UNKNOWN, "MM_SMS_STATE_UNKNOWN", "unknown" },
    { MM_SMS_STATE_STORED, "MM_SMS_STATE_STORED", "stored" },
    { MM_SMS_STATE_RECEIVING, "MM_SMS_STATE_RECEIVING", "receiving" },
    { MM_SMS_STATE_RECEIVED, "MM_SMS_STATE_RECEIVED", "received" },
    { MM_SMS_STATE_SENDING, "MM_SMS_STATE_SENDING", "sending" },
    { MM_SMS_STATE_SENT, "MM_SMS_STATE_SENT", "sent" },
    { 0, NULL, NULL }
};

GType
mm_sms_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSmsState"),
                                      mm_sms_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sms_state_get_string (MMSmsState val)
{
    guint i;

    for (i = 0; mm_sms_state_values[i].value_nick; i++) {
        if ((gint)val == mm_sms_state_values[i].value)
            return mm_sms_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sms_delivery_state_values[] = {
    { MM_SMS_DELIVERY_STATE_COMPLETED_RECEIVED, "MM_SMS_DELIVERY_STATE_COMPLETED_RECEIVED", "completed-received" },
    { MM_SMS_DELIVERY_STATE_COMPLETED_FORWARDED_UNCONFIRMED, "MM_SMS_DELIVERY_STATE_COMPLETED_FORWARDED_UNCONFIRMED", "completed-forwarded-unconfirmed" },
    { MM_SMS_DELIVERY_STATE_COMPLETED_REPLACED_BY_SC, "MM_SMS_DELIVERY_STATE_COMPLETED_REPLACED_BY_SC", "completed-replaced-by-sc" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_CONGESTION, "MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_CONGESTION", "temporary-error-congestion" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_SME_BUSY, "MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_SME_BUSY", "temporary-error-sme-busy" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_NO_RESPONSE_FROM_SME, "MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_NO_RESPONSE_FROM_SME", "temporary-error-no-response-from-sme" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_SERVICE_REJECTED, "MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_SERVICE_REJECTED", "temporary-error-service-rejected" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_QOS_NOT_AVAILABLE, "MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_QOS_NOT_AVAILABLE", "temporary-error-qos-not-available" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_IN_SME, "MM_SMS_DELIVERY_STATE_TEMPORARY_ERROR_IN_SME", "temporary-error-in-sme" },
    { MM_SMS_DELIVERY_STATE_ERROR_REMOTE_PROCEDURE, "MM_SMS_DELIVERY_STATE_ERROR_REMOTE_PROCEDURE", "error-remote-procedure" },
    { MM_SMS_DELIVERY_STATE_ERROR_INCOMPATIBLE_DESTINATION, "MM_SMS_DELIVERY_STATE_ERROR_INCOMPATIBLE_DESTINATION", "error-incompatible-destination" },
    { MM_SMS_DELIVERY_STATE_ERROR_CONNECTION_REJECTED, "MM_SMS_DELIVERY_STATE_ERROR_CONNECTION_REJECTED", "error-connection-rejected" },
    { MM_SMS_DELIVERY_STATE_ERROR_NOT_OBTAINABLE, "MM_SMS_DELIVERY_STATE_ERROR_NOT_OBTAINABLE", "error-not-obtainable" },
    { MM_SMS_DELIVERY_STATE_ERROR_QOS_NOT_AVAILABLE, "MM_SMS_DELIVERY_STATE_ERROR_QOS_NOT_AVAILABLE", "error-qos-not-available" },
    { MM_SMS_DELIVERY_STATE_ERROR_NO_INTERWORKING_AVAILABLE, "MM_SMS_DELIVERY_STATE_ERROR_NO_INTERWORKING_AVAILABLE", "error-no-interworking-available" },
    { MM_SMS_DELIVERY_STATE_ERROR_VALIDITY_PERIOD_EXPIRED, "MM_SMS_DELIVERY_STATE_ERROR_VALIDITY_PERIOD_EXPIRED", "error-validity-period-expired" },
    { MM_SMS_DELIVERY_STATE_ERROR_DELETED_BY_ORIGINATING_SME, "MM_SMS_DELIVERY_STATE_ERROR_DELETED_BY_ORIGINATING_SME", "error-deleted-by-originating-sme" },
    { MM_SMS_DELIVERY_STATE_ERROR_DELETED_BY_SC_ADMINISTRATION, "MM_SMS_DELIVERY_STATE_ERROR_DELETED_BY_SC_ADMINISTRATION", "error-deleted-by-sc-administration" },
    { MM_SMS_DELIVERY_STATE_ERROR_MESSAGE_DOES_NOT_EXIST, "MM_SMS_DELIVERY_STATE_ERROR_MESSAGE_DOES_NOT_EXIST", "error-message-does-not-exist" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_CONGESTION, "MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_CONGESTION", "temporary-fatal-error-congestion" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_SME_BUSY, "MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_SME_BUSY", "temporary-fatal-error-sme-busy" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_NO_RESPONSE_FROM_SME, "MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_NO_RESPONSE_FROM_SME", "temporary-fatal-error-no-response-from-sme" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_SERVICE_REJECTED, "MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_SERVICE_REJECTED", "temporary-fatal-error-service-rejected" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_QOS_NOT_AVAILABLE, "MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_QOS_NOT_AVAILABLE", "temporary-fatal-error-qos-not-available" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_IN_SME, "MM_SMS_DELIVERY_STATE_TEMPORARY_FATAL_ERROR_IN_SME", "temporary-fatal-error-in-sme" },
    { MM_SMS_DELIVERY_STATE_UNKNOWN, "MM_SMS_DELIVERY_STATE_UNKNOWN", "unknown" },
    { MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_ADDRESS_VACANT, "MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_ADDRESS_VACANT", "network-problem-address-vacant" },
    { MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_ADDRESS_TRANSLATION_FAILURE, "MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_ADDRESS_TRANSLATION_FAILURE", "network-problem-address-translation-failure" },
    { MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_NETWORK_RESOURCE_OUTAGE, "MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_NETWORK_RESOURCE_OUTAGE", "network-problem-network-resource-outage" },
    { MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_NETWORK_FAILURE, "MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_NETWORK_FAILURE", "network-problem-network-failure" },
    { MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_INVALID_TELESERVICE_ID, "MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_INVALID_TELESERVICE_ID", "network-problem-invalid-teleservice-id" },
    { MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_NETWORK_PROBLEM_OTHER", "network-problem-other" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_NO_PAGE_RESPONSE, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_NO_PAGE_RESPONSE", "terminal-problem-no-page-response" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_BUSY, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_BUSY", "terminal-problem-destination-busy" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_NO_ACKNOWLEDGMENT, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_NO_ACKNOWLEDGMENT", "terminal-problem-no-acknowledgment" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_RESOURCE_SHORTAGE, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_RESOURCE_SHORTAGE", "terminal-problem-destination-resource-shortage" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_SMS_DELIVERY_POSTPONED, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_SMS_DELIVERY_POSTPONED", "terminal-problem-sms-delivery-postponed" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_OUT_OF_SERVICE, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_OUT_OF_SERVICE", "terminal-problem-destination-out-of-service" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_NO_LONGER_AT_THIS_ADDRESS, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_DESTINATION_NO_LONGER_AT_THIS_ADDRESS", "terminal-problem-destination-no-longer-at-this-address" },
    { MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_TERMINAL_PROBLEM_OTHER", "terminal-problem-other" },
    { MM_SMS_DELIVERY_STATE_RADIO_INTERFACE_PROBLEM_RESOURCE_SHORTAGE, "MM_SMS_DELIVERY_STATE_RADIO_INTERFACE_PROBLEM_RESOURCE_SHORTAGE", "radio-interface-problem-resource-shortage" },
    { MM_SMS_DELIVERY_STATE_RADIO_INTERFACE_PROBLEM_INCOMPATIBILITY, "MM_SMS_DELIVERY_STATE_RADIO_INTERFACE_PROBLEM_INCOMPATIBILITY", "radio-interface-problem-incompatibility" },
    { MM_SMS_DELIVERY_STATE_RADIO_INTERFACE_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_RADIO_INTERFACE_PROBLEM_OTHER", "radio-interface-problem-other" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_ENCODING, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_ENCODING", "general-problem-encoding" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SMS_ORIGINATION_DENIED, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SMS_ORIGINATION_DENIED", "general-problem-sms-origination-denied" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SMS_TERMINATION_DENIED, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SMS_TERMINATION_DENIED", "general-problem-sms-termination-denied" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED", "general-problem-supplementary-service-not-supported" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SMS_NOT_SUPPORTED, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_SMS_NOT_SUPPORTED", "general-problem-sms-not-supported" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_MISSING_EXPECTED_PARAMETER, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_MISSING_EXPECTED_PARAMETER", "general-problem-missing-expected-parameter" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_MISSING_MANDATORY_PARAMETER, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_MISSING_MANDATORY_PARAMETER", "general-problem-missing-mandatory-parameter" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_UNRECOGNIZED_PARAMETER_VALUE, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_UNRECOGNIZED_PARAMETER_VALUE", "general-problem-unrecognized-parameter-value" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_UNEXPECTED_PARAMETER_VALUE, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_UNEXPECTED_PARAMETER_VALUE", "general-problem-unexpected-parameter-value" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_USER_DATA_SIZE_ERROR, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_USER_DATA_SIZE_ERROR", "general-problem-user-data-size-error" },
    { MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_GENERAL_PROBLEM_OTHER", "general-problem-other" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_ADDRESS_VACANT, "MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_ADDRESS_VACANT", "temporary-network-problem-address-vacant" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_ADDRESS_TRANSLATION_FAILURE, "MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_ADDRESS_TRANSLATION_FAILURE", "temporary-network-problem-address-translation-failure" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_NETWORK_RESOURCE_OUTAGE, "MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_NETWORK_RESOURCE_OUTAGE", "temporary-network-problem-network-resource-outage" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_NETWORK_FAILURE, "MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_NETWORK_FAILURE", "temporary-network-problem-network-failure" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_INVALID_TELESERVICE_ID, "MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_INVALID_TELESERVICE_ID", "temporary-network-problem-invalid-teleservice-id" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_TEMPORARY_NETWORK_PROBLEM_OTHER", "temporary-network-problem-other" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_NO_PAGE_RESPONSE, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_NO_PAGE_RESPONSE", "temporary-terminal-problem-no-page-response" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_BUSY, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_BUSY", "temporary-terminal-problem-destination-busy" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_NO_ACKNOWLEDGMENT, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_NO_ACKNOWLEDGMENT", "temporary-terminal-problem-no-acknowledgment" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_RESOURCE_SHORTAGE, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_RESOURCE_SHORTAGE", "temporary-terminal-problem-destination-resource-shortage" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_SMS_DELIVERY_POSTPONED, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_SMS_DELIVERY_POSTPONED", "temporary-terminal-problem-sms-delivery-postponed" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_OUT_OF_SERVICE, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_OUT_OF_SERVICE", "temporary-terminal-problem-destination-out-of-service" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_NO_LONGER_AT_THIS_ADDRESS, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_DESTINATION_NO_LONGER_AT_THIS_ADDRESS", "temporary-terminal-problem-destination-no-longer-at-this-address" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_TEMPORARY_TERMINAL_PROBLEM_OTHER", "temporary-terminal-problem-other" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_RADIO_INTERFACE_PROBLEM_RESOURCE_SHORTAGE, "MM_SMS_DELIVERY_STATE_TEMPORARY_RADIO_INTERFACE_PROBLEM_RESOURCE_SHORTAGE", "temporary-radio-interface-problem-resource-shortage" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_RADIO_INTERFACE_PROBLEM_INCOMPATIBILITY, "MM_SMS_DELIVERY_STATE_TEMPORARY_RADIO_INTERFACE_PROBLEM_INCOMPATIBILITY", "temporary-radio-interface-problem-incompatibility" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_RADIO_INTERFACE_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_TEMPORARY_RADIO_INTERFACE_PROBLEM_OTHER", "temporary-radio-interface-problem-other" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_ENCODING, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_ENCODING", "temporary-general-problem-encoding" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SMS_ORIGINATION_DENIED, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SMS_ORIGINATION_DENIED", "temporary-general-problem-sms-origination-denied" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SMS_TERMINATION_DENIED, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SMS_TERMINATION_DENIED", "temporary-general-problem-sms-termination-denied" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED", "temporary-general-problem-supplementary-service-not-supported" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SMS_NOT_SUPPORTED, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_SMS_NOT_SUPPORTED", "temporary-general-problem-sms-not-supported" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_MISSING_EXPECTED_PARAMETER, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_MISSING_EXPECTED_PARAMETER", "temporary-general-problem-missing-expected-parameter" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_MISSING_MANDATORY_PARAMETER, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_MISSING_MANDATORY_PARAMETER", "temporary-general-problem-missing-mandatory-parameter" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_UNRECOGNIZED_PARAMETER_VALUE, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_UNRECOGNIZED_PARAMETER_VALUE", "temporary-general-problem-unrecognized-parameter-value" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_UNEXPECTED_PARAMETER_VALUE, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_UNEXPECTED_PARAMETER_VALUE", "temporary-general-problem-unexpected-parameter-value" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_USER_DATA_SIZE_ERROR, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_USER_DATA_SIZE_ERROR", "temporary-general-problem-user-data-size-error" },
    { MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_OTHER, "MM_SMS_DELIVERY_STATE_TEMPORARY_GENERAL_PROBLEM_OTHER", "temporary-general-problem-other" },
    { 0, NULL, NULL }
};

GType
mm_sms_delivery_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSmsDeliveryState"),
                                      mm_sms_delivery_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sms_delivery_state_get_string (MMSmsDeliveryState val)
{
    guint i;

    for (i = 0; mm_sms_delivery_state_values[i].value_nick; i++) {
        if ((gint)val == mm_sms_delivery_state_values[i].value)
            return mm_sms_delivery_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sms_storage_values[] = {
    { MM_SMS_STORAGE_UNKNOWN, "MM_SMS_STORAGE_UNKNOWN", "unknown" },
    { MM_SMS_STORAGE_SM, "MM_SMS_STORAGE_SM", "sm" },
    { MM_SMS_STORAGE_ME, "MM_SMS_STORAGE_ME", "me" },
    { MM_SMS_STORAGE_MT, "MM_SMS_STORAGE_MT", "mt" },
    { MM_SMS_STORAGE_SR, "MM_SMS_STORAGE_SR", "sr" },
    { MM_SMS_STORAGE_BM, "MM_SMS_STORAGE_BM", "bm" },
    { MM_SMS_STORAGE_TA, "MM_SMS_STORAGE_TA", "ta" },
    { 0, NULL, NULL }
};

GType
mm_sms_storage_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSmsStorage"),
                                      mm_sms_storage_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sms_storage_get_string (MMSmsStorage val)
{
    guint i;

    for (i = 0; mm_sms_storage_values[i].value_nick; i++) {
        if ((gint)val == mm_sms_storage_values[i].value)
            return mm_sms_storage_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sms_validity_type_values[] = {
    { MM_SMS_VALIDITY_TYPE_UNKNOWN, "MM_SMS_VALIDITY_TYPE_UNKNOWN", "unknown" },
    { MM_SMS_VALIDITY_TYPE_RELATIVE, "MM_SMS_VALIDITY_TYPE_RELATIVE", "relative" },
    { MM_SMS_VALIDITY_TYPE_ABSOLUTE, "MM_SMS_VALIDITY_TYPE_ABSOLUTE", "absolute" },
    { MM_SMS_VALIDITY_TYPE_ENHANCED, "MM_SMS_VALIDITY_TYPE_ENHANCED", "enhanced" },
    { 0, NULL, NULL }
};

GType
mm_sms_validity_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSmsValidityType"),
                                      mm_sms_validity_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sms_validity_type_get_string (MMSmsValidityType val)
{
    guint i;

    for (i = 0; mm_sms_validity_type_values[i].value_nick; i++) {
        if ((gint)val == mm_sms_validity_type_values[i].value)
            return mm_sms_validity_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sms_cdma_teleservice_id_values[] = {
    { MM_SMS_CDMA_TELESERVICE_ID_UNKNOWN, "MM_SMS_CDMA_TELESERVICE_ID_UNKNOWN", "unknown" },
    { MM_SMS_CDMA_TELESERVICE_ID_CMT91, "MM_SMS_CDMA_TELESERVICE_ID_CMT91", "cmt91" },
    { MM_SMS_CDMA_TELESERVICE_ID_WPT, "MM_SMS_CDMA_TELESERVICE_ID_WPT", "wpt" },
    { MM_SMS_CDMA_TELESERVICE_ID_WMT, "MM_SMS_CDMA_TELESERVICE_ID_WMT", "wmt" },
    { MM_SMS_CDMA_TELESERVICE_ID_VMN, "MM_SMS_CDMA_TELESERVICE_ID_VMN", "vmn" },
    { MM_SMS_CDMA_TELESERVICE_ID_WAP, "MM_SMS_CDMA_TELESERVICE_ID_WAP", "wap" },
    { MM_SMS_CDMA_TELESERVICE_ID_WEMT, "MM_SMS_CDMA_TELESERVICE_ID_WEMT", "wemt" },
    { MM_SMS_CDMA_TELESERVICE_ID_SCPT, "MM_SMS_CDMA_TELESERVICE_ID_SCPT", "scpt" },
    { MM_SMS_CDMA_TELESERVICE_ID_CATPT, "MM_SMS_CDMA_TELESERVICE_ID_CATPT", "catpt" },
    { 0, NULL, NULL }
};

GType
mm_sms_cdma_teleservice_id_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSmsCdmaTeleserviceId"),
                                      mm_sms_cdma_teleservice_id_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sms_cdma_teleservice_id_get_string (MMSmsCdmaTeleserviceId val)
{
    guint i;

    for (i = 0; mm_sms_cdma_teleservice_id_values[i].value_nick; i++) {
        if ((gint)val == mm_sms_cdma_teleservice_id_values[i].value)
            return mm_sms_cdma_teleservice_id_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sms_cdma_service_category_values[] = {
    { MM_SMS_CDMA_SERVICE_CATEGORY_UNKNOWN, "MM_SMS_CDMA_SERVICE_CATEGORY_UNKNOWN", "unknown" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_EMERGENCY_BROADCAST, "MM_SMS_CDMA_SERVICE_CATEGORY_EMERGENCY_BROADCAST", "emergency-broadcast" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_ADMINISTRATIVE, "MM_SMS_CDMA_SERVICE_CATEGORY_ADMINISTRATIVE", "administrative" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_MAINTENANCE, "MM_SMS_CDMA_SERVICE_CATEGORY_MAINTENANCE", "maintenance" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_LOCAL, "MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_LOCAL", "general-news-local" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_REGIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_REGIONAL", "general-news-regional" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_NATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_NATIONAL", "general-news-national" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_INTERNATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_GENERAL_NEWS_INTERNATIONAL", "general-news-international" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_LOCAL, "MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_LOCAL", "business-news-local" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_REGIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_REGIONAL", "business-news-regional" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_NATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_NATIONAL", "business-news-national" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_INTERNATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_BUSINESS_NEWS_INTERNATIONAL", "business-news-international" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_LOCAL, "MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_LOCAL", "sports-news-local" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_REGIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_REGIONAL", "sports-news-regional" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_NATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_NATIONAL", "sports-news-national" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_INTERNATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_SPORTS_NEWS_INTERNATIONAL", "sports-news-international" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_LOCAL, "MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_LOCAL", "entertainment-news-local" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_REGIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_REGIONAL", "entertainment-news-regional" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_NATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_NATIONAL", "entertainment-news-national" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_INTERNATIONAL, "MM_SMS_CDMA_SERVICE_CATEGORY_ENTERTAINMENT_NEWS_INTERNATIONAL", "entertainment-news-international" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_LOCAL_WEATHER, "MM_SMS_CDMA_SERVICE_CATEGORY_LOCAL_WEATHER", "local-weather" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_TRAFFIC_REPORT, "MM_SMS_CDMA_SERVICE_CATEGORY_TRAFFIC_REPORT", "traffic-report" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_FLIGHT_SCHEDULES, "MM_SMS_CDMA_SERVICE_CATEGORY_FLIGHT_SCHEDULES", "flight-schedules" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_RESTAURANTS, "MM_SMS_CDMA_SERVICE_CATEGORY_RESTAURANTS", "restaurants" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_LODGINGS, "MM_SMS_CDMA_SERVICE_CATEGORY_LODGINGS", "lodgings" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_RETAIL_DIRECTORY, "MM_SMS_CDMA_SERVICE_CATEGORY_RETAIL_DIRECTORY", "retail-directory" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_ADVERTISEMENTS, "MM_SMS_CDMA_SERVICE_CATEGORY_ADVERTISEMENTS", "advertisements" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_STOCK_QUOTES, "MM_SMS_CDMA_SERVICE_CATEGORY_STOCK_QUOTES", "stock-quotes" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_EMPLOYMENT, "MM_SMS_CDMA_SERVICE_CATEGORY_EMPLOYMENT", "employment" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_HOSPITALS, "MM_SMS_CDMA_SERVICE_CATEGORY_HOSPITALS", "hospitals" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_TECHNOLOGY_NEWS, "MM_SMS_CDMA_SERVICE_CATEGORY_TECHNOLOGY_NEWS", "technology-news" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_MULTICATEGORY, "MM_SMS_CDMA_SERVICE_CATEGORY_MULTICATEGORY", "multicategory" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_PRESIDENTIAL_ALERT, "MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_PRESIDENTIAL_ALERT", "cmas-presidential-alert" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_EXTREME_THREAT, "MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_EXTREME_THREAT", "cmas-extreme-threat" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_SEVERE_THREAT, "MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_SEVERE_THREAT", "cmas-severe-threat" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_CHILD_ABDUCTION_EMERGENCY, "MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_CHILD_ABDUCTION_EMERGENCY", "cmas-child-abduction-emergency" },
    { MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_TEST, "MM_SMS_CDMA_SERVICE_CATEGORY_CMAS_TEST", "cmas-test" },
    { 0, NULL, NULL }
};

GType
mm_sms_cdma_service_category_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSmsCdmaServiceCategory"),
                                      mm_sms_cdma_service_category_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sms_cdma_service_category_get_string (MMSmsCdmaServiceCategory val)
{
    guint i;

    for (i = 0; mm_sms_cdma_service_category_values[i].value_nick; i++) {
        if ((gint)val == mm_sms_cdma_service_category_values[i].value)
            return mm_sms_cdma_service_category_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_cbm_state_values[] = {
    { MM_CBM_STATE_UNKNOWN, "MM_CBM_STATE_UNKNOWN", "unknown" },
    { MM_CBM_STATE_RECEIVING, "MM_CBM_STATE_RECEIVING", "receiving" },
    { MM_CBM_STATE_RECEIVED, "MM_CBM_STATE_RECEIVED", "received" },
    { 0, NULL, NULL }
};

GType
mm_cbm_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMCbmState"),
                                      mm_cbm_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_cbm_state_get_string (MMCbmState val)
{
    guint i;

    for (i = 0; mm_cbm_state_values[i].value_nick; i++) {
        if ((gint)val == mm_cbm_state_values[i].value)
            return mm_cbm_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_contacts_storage_values[] = {
    { MM_MODEM_CONTACTS_STORAGE_UNKNOWN, "MM_MODEM_CONTACTS_STORAGE_UNKNOWN", "unknown" },
    { MM_MODEM_CONTACTS_STORAGE_ME, "MM_MODEM_CONTACTS_STORAGE_ME", "me" },
    { MM_MODEM_CONTACTS_STORAGE_SM, "MM_MODEM_CONTACTS_STORAGE_SM", "sm" },
    { MM_MODEM_CONTACTS_STORAGE_MT, "MM_MODEM_CONTACTS_STORAGE_MT", "mt" },
    { 0, NULL, NULL }
};

GType
mm_modem_contacts_storage_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemContactsStorage"),
                                      mm_modem_contacts_storage_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_contacts_storage_get_string (MMModemContactsStorage val)
{
    guint i;

    for (i = 0; mm_modem_contacts_storage_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_contacts_storage_values[i].value)
            return mm_modem_contacts_storage_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_bearer_type_values[] = {
    { MM_BEARER_TYPE_UNKNOWN, "MM_BEARER_TYPE_UNKNOWN", "unknown" },
    { MM_BEARER_TYPE_DEFAULT, "MM_BEARER_TYPE_DEFAULT", "default" },
    { MM_BEARER_TYPE_DEFAULT_ATTACH, "MM_BEARER_TYPE_DEFAULT_ATTACH", "default-attach" },
    { MM_BEARER_TYPE_DEDICATED, "MM_BEARER_TYPE_DEDICATED", "dedicated" },
    { 0, NULL, NULL }
};

GType
mm_bearer_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMBearerType"),
                                      mm_bearer_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_bearer_type_get_string (MMBearerType val)
{
    guint i;

    for (i = 0; mm_bearer_type_values[i].value_nick; i++) {
        if ((gint)val == mm_bearer_type_values[i].value)
            return mm_bearer_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_bearer_ip_method_values[] = {
    { MM_BEARER_IP_METHOD_UNKNOWN, "MM_BEARER_IP_METHOD_UNKNOWN", "unknown" },
    { MM_BEARER_IP_METHOD_PPP, "MM_BEARER_IP_METHOD_PPP", "ppp" },
    { MM_BEARER_IP_METHOD_STATIC, "MM_BEARER_IP_METHOD_STATIC", "static" },
    { MM_BEARER_IP_METHOD_DHCP, "MM_BEARER_IP_METHOD_DHCP", "dhcp" },
    { 0, NULL, NULL }
};

GType
mm_bearer_ip_method_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMBearerIpMethod"),
                                      mm_bearer_ip_method_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_bearer_ip_method_get_string (MMBearerIpMethod val)
{
    guint i;

    for (i = 0; mm_bearer_ip_method_values[i].value_nick; i++) {
        if ((gint)val == mm_bearer_ip_method_values[i].value)
            return mm_bearer_ip_method_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_cdma_registration_state_values[] = {
    { MM_MODEM_CDMA_REGISTRATION_STATE_UNKNOWN, "MM_MODEM_CDMA_REGISTRATION_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_CDMA_REGISTRATION_STATE_REGISTERED, "MM_MODEM_CDMA_REGISTRATION_STATE_REGISTERED", "registered" },
    { MM_MODEM_CDMA_REGISTRATION_STATE_HOME, "MM_MODEM_CDMA_REGISTRATION_STATE_HOME", "home" },
    { MM_MODEM_CDMA_REGISTRATION_STATE_ROAMING, "MM_MODEM_CDMA_REGISTRATION_STATE_ROAMING", "roaming" },
    { 0, NULL, NULL }
};

GType
mm_modem_cdma_registration_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemCdmaRegistrationState"),
                                      mm_modem_cdma_registration_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_cdma_registration_state_get_string (MMModemCdmaRegistrationState val)
{
    guint i;

    for (i = 0; mm_modem_cdma_registration_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_cdma_registration_state_values[i].value)
            return mm_modem_cdma_registration_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_cdma_activation_state_values[] = {
    { MM_MODEM_CDMA_ACTIVATION_STATE_UNKNOWN, "MM_MODEM_CDMA_ACTIVATION_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_CDMA_ACTIVATION_STATE_NOT_ACTIVATED, "MM_MODEM_CDMA_ACTIVATION_STATE_NOT_ACTIVATED", "not-activated" },
    { MM_MODEM_CDMA_ACTIVATION_STATE_ACTIVATING, "MM_MODEM_CDMA_ACTIVATION_STATE_ACTIVATING", "activating" },
    { MM_MODEM_CDMA_ACTIVATION_STATE_PARTIALLY_ACTIVATED, "MM_MODEM_CDMA_ACTIVATION_STATE_PARTIALLY_ACTIVATED", "partially-activated" },
    { MM_MODEM_CDMA_ACTIVATION_STATE_ACTIVATED, "MM_MODEM_CDMA_ACTIVATION_STATE_ACTIVATED", "activated" },
    { 0, NULL, NULL }
};

GType
mm_modem_cdma_activation_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemCdmaActivationState"),
                                      mm_modem_cdma_activation_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_cdma_activation_state_get_string (MMModemCdmaActivationState val)
{
    guint i;

    for (i = 0; mm_modem_cdma_activation_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_cdma_activation_state_values[i].value)
            return mm_modem_cdma_activation_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_cdma_rm_protocol_values[] = {
    { MM_MODEM_CDMA_RM_PROTOCOL_UNKNOWN, "MM_MODEM_CDMA_RM_PROTOCOL_UNKNOWN", "unknown" },
    { MM_MODEM_CDMA_RM_PROTOCOL_ASYNC, "MM_MODEM_CDMA_RM_PROTOCOL_ASYNC", "async" },
    { MM_MODEM_CDMA_RM_PROTOCOL_PACKET_RELAY, "MM_MODEM_CDMA_RM_PROTOCOL_PACKET_RELAY", "packet-relay" },
    { MM_MODEM_CDMA_RM_PROTOCOL_PACKET_NETWORK_PPP, "MM_MODEM_CDMA_RM_PROTOCOL_PACKET_NETWORK_PPP", "packet-network-ppp" },
    { MM_MODEM_CDMA_RM_PROTOCOL_PACKET_NETWORK_SLIP, "MM_MODEM_CDMA_RM_PROTOCOL_PACKET_NETWORK_SLIP", "packet-network-slip" },
    { MM_MODEM_CDMA_RM_PROTOCOL_STU_III, "MM_MODEM_CDMA_RM_PROTOCOL_STU_III", "stu-iii" },
    { 0, NULL, NULL }
};

GType
mm_modem_cdma_rm_protocol_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModemCdmaRmProtocol"),
                                      mm_modem_cdma_rm_protocol_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_cdma_rm_protocol_get_string (MMModemCdmaRmProtocol val)
{
    guint i;

    for (i = 0; mm_modem_cdma_rm_protocol_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_cdma_rm_protocol_values[i].value)
            return mm_modem_cdma_rm_protocol_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_registration_state_values[] = {
    { MM_MODEM_3GPP_REGISTRATION_STATE_IDLE, "MM_MODEM_3GPP_REGISTRATION_STATE_IDLE", "idle" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_HOME, "MM_MODEM_3GPP_REGISTRATION_STATE_HOME", "home" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_SEARCHING, "MM_MODEM_3GPP_REGISTRATION_STATE_SEARCHING", "searching" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_DENIED, "MM_MODEM_3GPP_REGISTRATION_STATE_DENIED", "denied" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_UNKNOWN, "MM_MODEM_3GPP_REGISTRATION_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_ROAMING, "MM_MODEM_3GPP_REGISTRATION_STATE_ROAMING", "roaming" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_HOME_SMS_ONLY, "MM_MODEM_3GPP_REGISTRATION_STATE_HOME_SMS_ONLY", "home-sms-only" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_ROAMING_SMS_ONLY, "MM_MODEM_3GPP_REGISTRATION_STATE_ROAMING_SMS_ONLY", "roaming-sms-only" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_EMERGENCY_ONLY, "MM_MODEM_3GPP_REGISTRATION_STATE_EMERGENCY_ONLY", "emergency-only" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_HOME_CSFB_NOT_PREFERRED, "MM_MODEM_3GPP_REGISTRATION_STATE_HOME_CSFB_NOT_PREFERRED", "home-csfb-not-preferred" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_ROAMING_CSFB_NOT_PREFERRED, "MM_MODEM_3GPP_REGISTRATION_STATE_ROAMING_CSFB_NOT_PREFERRED", "roaming-csfb-not-preferred" },
    { MM_MODEM_3GPP_REGISTRATION_STATE_ATTACHED_RLOS, "MM_MODEM_3GPP_REGISTRATION_STATE_ATTACHED_RLOS", "attached-rlos" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_registration_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppRegistrationState"),
                                      mm_modem_3gpp_registration_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_registration_state_get_string (MMModem3gppRegistrationState val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_registration_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_registration_state_values[i].value)
            return mm_modem_3gpp_registration_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_network_availability_values[] = {
    { MM_MODEM_3GPP_NETWORK_AVAILABILITY_UNKNOWN, "MM_MODEM_3GPP_NETWORK_AVAILABILITY_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_NETWORK_AVAILABILITY_AVAILABLE, "MM_MODEM_3GPP_NETWORK_AVAILABILITY_AVAILABLE", "available" },
    { MM_MODEM_3GPP_NETWORK_AVAILABILITY_CURRENT, "MM_MODEM_3GPP_NETWORK_AVAILABILITY_CURRENT", "current" },
    { MM_MODEM_3GPP_NETWORK_AVAILABILITY_FORBIDDEN, "MM_MODEM_3GPP_NETWORK_AVAILABILITY_FORBIDDEN", "forbidden" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_network_availability_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppNetworkAvailability"),
                                      mm_modem_3gpp_network_availability_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_network_availability_get_string (MMModem3gppNetworkAvailability val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_network_availability_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_network_availability_values[i].value)
            return mm_modem_3gpp_network_availability_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_subscription_state_values[] = {
    { MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNKNOWN, "MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNPROVISIONED, "MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNPROVISIONED", "unprovisioned" },
    { MM_MODEM_3GPP_SUBSCRIPTION_STATE_PROVISIONED, "MM_MODEM_3GPP_SUBSCRIPTION_STATE_PROVISIONED", "provisioned" },
    { MM_MODEM_3GPP_SUBSCRIPTION_STATE_OUT_OF_DATA, "MM_MODEM_3GPP_SUBSCRIPTION_STATE_OUT_OF_DATA", "out-of-data" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_subscription_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppSubscriptionState"),
                                      mm_modem_3gpp_subscription_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_subscription_state_get_string (MMModem3gppSubscriptionState val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_subscription_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_subscription_state_values[i].value)
            return mm_modem_3gpp_subscription_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_ussd_session_state_values[] = {
    { MM_MODEM_3GPP_USSD_SESSION_STATE_UNKNOWN, "MM_MODEM_3GPP_USSD_SESSION_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_USSD_SESSION_STATE_IDLE, "MM_MODEM_3GPP_USSD_SESSION_STATE_IDLE", "idle" },
    { MM_MODEM_3GPP_USSD_SESSION_STATE_ACTIVE, "MM_MODEM_3GPP_USSD_SESSION_STATE_ACTIVE", "active" },
    { MM_MODEM_3GPP_USSD_SESSION_STATE_USER_RESPONSE, "MM_MODEM_3GPP_USSD_SESSION_STATE_USER_RESPONSE", "user-response" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_ussd_session_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppUssdSessionState"),
                                      mm_modem_3gpp_ussd_session_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_ussd_session_state_get_string (MMModem3gppUssdSessionState val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_ussd_session_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_ussd_session_state_values[i].value)
            return mm_modem_3gpp_ussd_session_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_eps_ue_mode_operation_values[] = {
    { MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_UNKNOWN, "MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_PS_1, "MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_PS_1", "ps-1" },
    { MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_PS_2, "MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_PS_2", "ps-2" },
    { MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_CSPS_1, "MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_CSPS_1", "csps-1" },
    { MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_CSPS_2, "MM_MODEM_3GPP_EPS_UE_MODE_OPERATION_CSPS_2", "csps-2" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_eps_ue_mode_operation_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppEpsUeModeOperation"),
                                      mm_modem_3gpp_eps_ue_mode_operation_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_eps_ue_mode_operation_get_string (MMModem3gppEpsUeModeOperation val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_eps_ue_mode_operation_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_eps_ue_mode_operation_values[i].value)
            return mm_modem_3gpp_eps_ue_mode_operation_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_firmware_image_type_values[] = {
    { MM_FIRMWARE_IMAGE_TYPE_UNKNOWN, "MM_FIRMWARE_IMAGE_TYPE_UNKNOWN", "unknown" },
    { MM_FIRMWARE_IMAGE_TYPE_GENERIC, "MM_FIRMWARE_IMAGE_TYPE_GENERIC", "generic" },
    { MM_FIRMWARE_IMAGE_TYPE_GOBI, "MM_FIRMWARE_IMAGE_TYPE_GOBI", "gobi" },
    { 0, NULL, NULL }
};

GType
mm_firmware_image_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMFirmwareImageType"),
                                      mm_firmware_image_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_firmware_image_type_get_string (MMFirmwareImageType val)
{
    guint i;

    for (i = 0; mm_firmware_image_type_values[i].value_nick; i++) {
        if ((gint)val == mm_firmware_image_type_values[i].value)
            return mm_firmware_image_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_oma_session_type_values[] = {
    { MM_OMA_SESSION_TYPE_UNKNOWN, "MM_OMA_SESSION_TYPE_UNKNOWN", "unknown" },
    { MM_OMA_SESSION_TYPE_CLIENT_INITIATED_DEVICE_CONFIGURE, "MM_OMA_SESSION_TYPE_CLIENT_INITIATED_DEVICE_CONFIGURE", "client-initiated-device-configure" },
    { MM_OMA_SESSION_TYPE_CLIENT_INITIATED_PRL_UPDATE, "MM_OMA_SESSION_TYPE_CLIENT_INITIATED_PRL_UPDATE", "client-initiated-prl-update" },
    { MM_OMA_SESSION_TYPE_CLIENT_INITIATED_HANDS_FREE_ACTIVATION, "MM_OMA_SESSION_TYPE_CLIENT_INITIATED_HANDS_FREE_ACTIVATION", "client-initiated-hands-free-activation" },
    { MM_OMA_SESSION_TYPE_NETWORK_INITIATED_DEVICE_CONFIGURE, "MM_OMA_SESSION_TYPE_NETWORK_INITIATED_DEVICE_CONFIGURE", "network-initiated-device-configure" },
    { MM_OMA_SESSION_TYPE_NETWORK_INITIATED_PRL_UPDATE, "MM_OMA_SESSION_TYPE_NETWORK_INITIATED_PRL_UPDATE", "network-initiated-prl-update" },
    { MM_OMA_SESSION_TYPE_DEVICE_INITIATED_PRL_UPDATE, "MM_OMA_SESSION_TYPE_DEVICE_INITIATED_PRL_UPDATE", "device-initiated-prl-update" },
    { MM_OMA_SESSION_TYPE_DEVICE_INITIATED_HANDS_FREE_ACTIVATION, "MM_OMA_SESSION_TYPE_DEVICE_INITIATED_HANDS_FREE_ACTIVATION", "device-initiated-hands-free-activation" },
    { 0, NULL, NULL }
};

GType
mm_oma_session_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMOmaSessionType"),
                                      mm_oma_session_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_oma_session_type_get_string (MMOmaSessionType val)
{
    guint i;

    for (i = 0; mm_oma_session_type_values[i].value_nick; i++) {
        if ((gint)val == mm_oma_session_type_values[i].value)
            return mm_oma_session_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_oma_session_state_values[] = {
    { MM_OMA_SESSION_STATE_FAILED, "MM_OMA_SESSION_STATE_FAILED", "failed" },
    { MM_OMA_SESSION_STATE_UNKNOWN, "MM_OMA_SESSION_STATE_UNKNOWN", "unknown" },
    { MM_OMA_SESSION_STATE_STARTED, "MM_OMA_SESSION_STATE_STARTED", "started" },
    { MM_OMA_SESSION_STATE_RETRYING, "MM_OMA_SESSION_STATE_RETRYING", "retrying" },
    { MM_OMA_SESSION_STATE_CONNECTING, "MM_OMA_SESSION_STATE_CONNECTING", "connecting" },
    { MM_OMA_SESSION_STATE_CONNECTED, "MM_OMA_SESSION_STATE_CONNECTED", "connected" },
    { MM_OMA_SESSION_STATE_AUTHENTICATED, "MM_OMA_SESSION_STATE_AUTHENTICATED", "authenticated" },
    { MM_OMA_SESSION_STATE_MDN_DOWNLOADED, "MM_OMA_SESSION_STATE_MDN_DOWNLOADED", "mdn-downloaded" },
    { MM_OMA_SESSION_STATE_MSID_DOWNLOADED, "MM_OMA_SESSION_STATE_MSID_DOWNLOADED", "msid-downloaded" },
    { MM_OMA_SESSION_STATE_PRL_DOWNLOADED, "MM_OMA_SESSION_STATE_PRL_DOWNLOADED", "prl-downloaded" },
    { MM_OMA_SESSION_STATE_MIP_PROFILE_DOWNLOADED, "MM_OMA_SESSION_STATE_MIP_PROFILE_DOWNLOADED", "mip-profile-downloaded" },
    { MM_OMA_SESSION_STATE_COMPLETED, "MM_OMA_SESSION_STATE_COMPLETED", "completed" },
    { 0, NULL, NULL }
};

GType
mm_oma_session_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMOmaSessionState"),
                                      mm_oma_session_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_oma_session_state_get_string (MMOmaSessionState val)
{
    guint i;

    for (i = 0; mm_oma_session_state_values[i].value_nick; i++) {
        if ((gint)val == mm_oma_session_state_values[i].value)
            return mm_oma_session_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_oma_session_state_failed_reason_values[] = {
    { MM_OMA_SESSION_STATE_FAILED_REASON_UNKNOWN, "MM_OMA_SESSION_STATE_FAILED_REASON_UNKNOWN", "unknown" },
    { MM_OMA_SESSION_STATE_FAILED_REASON_NETWORK_UNAVAILABLE, "MM_OMA_SESSION_STATE_FAILED_REASON_NETWORK_UNAVAILABLE", "network-unavailable" },
    { MM_OMA_SESSION_STATE_FAILED_REASON_SERVER_UNAVAILABLE, "MM_OMA_SESSION_STATE_FAILED_REASON_SERVER_UNAVAILABLE", "server-unavailable" },
    { MM_OMA_SESSION_STATE_FAILED_REASON_AUTHENTICATION_FAILED, "MM_OMA_SESSION_STATE_FAILED_REASON_AUTHENTICATION_FAILED", "authentication-failed" },
    { MM_OMA_SESSION_STATE_FAILED_REASON_MAX_RETRY_EXCEEDED, "MM_OMA_SESSION_STATE_FAILED_REASON_MAX_RETRY_EXCEEDED", "max-retry-exceeded" },
    { MM_OMA_SESSION_STATE_FAILED_REASON_SESSION_CANCELLED, "MM_OMA_SESSION_STATE_FAILED_REASON_SESSION_CANCELLED", "session-cancelled" },
    { 0, NULL, NULL }
};

GType
mm_oma_session_state_failed_reason_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMOmaSessionStateFailedReason"),
                                      mm_oma_session_state_failed_reason_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_oma_session_state_failed_reason_get_string (MMOmaSessionStateFailedReason val)
{
    guint i;

    for (i = 0; mm_oma_session_state_failed_reason_values[i].value_nick; i++) {
        if ((gint)val == mm_oma_session_state_failed_reason_values[i].value)
            return mm_oma_session_state_failed_reason_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_call_state_values[] = {
    { MM_CALL_STATE_UNKNOWN, "MM_CALL_STATE_UNKNOWN", "unknown" },
    { MM_CALL_STATE_DIALING, "MM_CALL_STATE_DIALING", "dialing" },
    { MM_CALL_STATE_RINGING_OUT, "MM_CALL_STATE_RINGING_OUT", "ringing-out" },
    { MM_CALL_STATE_RINGING_IN, "MM_CALL_STATE_RINGING_IN", "ringing-in" },
    { MM_CALL_STATE_ACTIVE, "MM_CALL_STATE_ACTIVE", "active" },
    { MM_CALL_STATE_HELD, "MM_CALL_STATE_HELD", "held" },
    { MM_CALL_STATE_WAITING, "MM_CALL_STATE_WAITING", "waiting" },
    { MM_CALL_STATE_TERMINATED, "MM_CALL_STATE_TERMINATED", "terminated" },
    { 0, NULL, NULL }
};

GType
mm_call_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMCallState"),
                                      mm_call_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_call_state_get_string (MMCallState val)
{
    guint i;

    for (i = 0; mm_call_state_values[i].value_nick; i++) {
        if ((gint)val == mm_call_state_values[i].value)
            return mm_call_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_call_state_reason_values[] = {
    { MM_CALL_STATE_REASON_UNKNOWN, "MM_CALL_STATE_REASON_UNKNOWN", "unknown" },
    { MM_CALL_STATE_REASON_OUTGOING_STARTED, "MM_CALL_STATE_REASON_OUTGOING_STARTED", "outgoing-started" },
    { MM_CALL_STATE_REASON_INCOMING_NEW, "MM_CALL_STATE_REASON_INCOMING_NEW", "incoming-new" },
    { MM_CALL_STATE_REASON_ACCEPTED, "MM_CALL_STATE_REASON_ACCEPTED", "accepted" },
    { MM_CALL_STATE_REASON_TERMINATED, "MM_CALL_STATE_REASON_TERMINATED", "terminated" },
    { MM_CALL_STATE_REASON_REFUSED_OR_BUSY, "MM_CALL_STATE_REASON_REFUSED_OR_BUSY", "refused-or-busy" },
    { MM_CALL_STATE_REASON_ERROR, "MM_CALL_STATE_REASON_ERROR", "error" },
    { MM_CALL_STATE_REASON_AUDIO_SETUP_FAILED, "MM_CALL_STATE_REASON_AUDIO_SETUP_FAILED", "audio-setup-failed" },
    { MM_CALL_STATE_REASON_TRANSFERRED, "MM_CALL_STATE_REASON_TRANSFERRED", "transferred" },
    { MM_CALL_STATE_REASON_DEFLECTED, "MM_CALL_STATE_REASON_DEFLECTED", "deflected" },
    { 0, NULL, NULL }
};

GType
mm_call_state_reason_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMCallStateReason"),
                                      mm_call_state_reason_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_call_state_reason_get_string (MMCallStateReason val)
{
    guint i;

    for (i = 0; mm_call_state_reason_values[i].value_nick; i++) {
        if ((gint)val == mm_call_state_reason_values[i].value)
            return mm_call_state_reason_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_call_direction_values[] = {
    { MM_CALL_DIRECTION_UNKNOWN, "MM_CALL_DIRECTION_UNKNOWN", "unknown" },
    { MM_CALL_DIRECTION_INCOMING, "MM_CALL_DIRECTION_INCOMING", "incoming" },
    { MM_CALL_DIRECTION_OUTGOING, "MM_CALL_DIRECTION_OUTGOING", "outgoing" },
    { 0, NULL, NULL }
};

GType
mm_call_direction_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMCallDirection"),
                                      mm_call_direction_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_call_direction_get_string (MMCallDirection val)
{
    guint i;

    for (i = 0; mm_call_direction_values[i].value_nick; i++) {
        if ((gint)val == mm_call_direction_values[i].value)
            return mm_call_direction_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_bearer_multiplex_support_values[] = {
    { MM_BEARER_MULTIPLEX_SUPPORT_UNKNOWN, "MM_BEARER_MULTIPLEX_SUPPORT_UNKNOWN", "unknown" },
    { MM_BEARER_MULTIPLEX_SUPPORT_NONE, "MM_BEARER_MULTIPLEX_SUPPORT_NONE", "none" },
    { MM_BEARER_MULTIPLEX_SUPPORT_REQUESTED, "MM_BEARER_MULTIPLEX_SUPPORT_REQUESTED", "requested" },
    { MM_BEARER_MULTIPLEX_SUPPORT_REQUIRED, "MM_BEARER_MULTIPLEX_SUPPORT_REQUIRED", "required" },
    { 0, NULL, NULL }
};

GType
mm_bearer_multiplex_support_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMBearerMultiplexSupport"),
                                      mm_bearer_multiplex_support_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_bearer_multiplex_support_get_string (MMBearerMultiplexSupport val)
{
    guint i;

    for (i = 0; mm_bearer_multiplex_support_values[i].value_nick; i++) {
        if ((gint)val == mm_bearer_multiplex_support_values[i].value)
            return mm_bearer_multiplex_support_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_packet_service_state_values[] = {
    { MM_MODEM_3GPP_PACKET_SERVICE_STATE_UNKNOWN, "MM_MODEM_3GPP_PACKET_SERVICE_STATE_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_PACKET_SERVICE_STATE_DETACHED, "MM_MODEM_3GPP_PACKET_SERVICE_STATE_DETACHED", "detached" },
    { MM_MODEM_3GPP_PACKET_SERVICE_STATE_ATTACHED, "MM_MODEM_3GPP_PACKET_SERVICE_STATE_ATTACHED", "attached" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_packet_service_state_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppPacketServiceState"),
                                      mm_modem_3gpp_packet_service_state_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_packet_service_state_get_string (MMModem3gppPacketServiceState val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_packet_service_state_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_packet_service_state_values[i].value)
            return mm_modem_3gpp_packet_service_state_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sim_type_values[] = {
    { MM_SIM_TYPE_UNKNOWN, "MM_SIM_TYPE_UNKNOWN", "unknown" },
    { MM_SIM_TYPE_PHYSICAL, "MM_SIM_TYPE_PHYSICAL", "physical" },
    { MM_SIM_TYPE_ESIM, "MM_SIM_TYPE_ESIM", "esim" },
    { 0, NULL, NULL }
};

GType
mm_sim_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSimType"),
                                      mm_sim_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sim_type_get_string (MMSimType val)
{
    guint i;

    for (i = 0; mm_sim_type_values[i].value_nick; i++) {
        if ((gint)val == mm_sim_type_values[i].value)
            return mm_sim_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sim_esim_status_values[] = {
    { MM_SIM_ESIM_STATUS_UNKNOWN, "MM_SIM_ESIM_STATUS_UNKNOWN", "unknown" },
    { MM_SIM_ESIM_STATUS_NO_PROFILES, "MM_SIM_ESIM_STATUS_NO_PROFILES", "no-profiles" },
    { MM_SIM_ESIM_STATUS_WITH_PROFILES, "MM_SIM_ESIM_STATUS_WITH_PROFILES", "with-profiles" },
    { 0, NULL, NULL }
};

GType
mm_sim_esim_status_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSimEsimStatus"),
                                      mm_sim_esim_status_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sim_esim_status_get_string (MMSimEsimStatus val)
{
    guint i;

    for (i = 0; mm_sim_esim_status_values[i].value_nick; i++) {
        if ((gint)val == mm_sim_esim_status_values[i].value)
            return mm_sim_esim_status_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_sim_removability_values[] = {
    { MM_SIM_REMOVABILITY_UNKNOWN, "MM_SIM_REMOVABILITY_UNKNOWN", "unknown" },
    { MM_SIM_REMOVABILITY_REMOVABLE, "MM_SIM_REMOVABILITY_REMOVABLE", "removable" },
    { MM_SIM_REMOVABILITY_NOT_REMOVABLE, "MM_SIM_REMOVABILITY_NOT_REMOVABLE", "not-removable" },
    { 0, NULL, NULL }
};

GType
mm_sim_removability_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMSimRemovability"),
                                      mm_sim_removability_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_sim_removability_get_string (MMSimRemovability val)
{
    guint i;

    for (i = 0; mm_sim_removability_values[i].value_nick; i++) {
        if ((gint)val == mm_sim_removability_values[i].value)
            return mm_sim_removability_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_mico_mode_values[] = {
    { MM_MODEM_3GPP_MICO_MODE_UNKNOWN, "MM_MODEM_3GPP_MICO_MODE_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_MICO_MODE_UNSUPPORTED, "MM_MODEM_3GPP_MICO_MODE_UNSUPPORTED", "unsupported" },
    { MM_MODEM_3GPP_MICO_MODE_DISABLED, "MM_MODEM_3GPP_MICO_MODE_DISABLED", "disabled" },
    { MM_MODEM_3GPP_MICO_MODE_ENABLED, "MM_MODEM_3GPP_MICO_MODE_ENABLED", "enabled" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_mico_mode_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppMicoMode"),
                                      mm_modem_3gpp_mico_mode_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_mico_mode_get_string (MMModem3gppMicoMode val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_mico_mode_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_mico_mode_values[i].value)
            return mm_modem_3gpp_mico_mode_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_modem_3gpp_drx_cycle_values[] = {
    { MM_MODEM_3GPP_DRX_CYCLE_UNKNOWN, "MM_MODEM_3GPP_DRX_CYCLE_UNKNOWN", "unknown" },
    { MM_MODEM_3GPP_DRX_CYCLE_UNSUPPORTED, "MM_MODEM_3GPP_DRX_CYCLE_UNSUPPORTED", "unsupported" },
    { MM_MODEM_3GPP_DRX_CYCLE_32, "MM_MODEM_3GPP_DRX_CYCLE_32", "32" },
    { MM_MODEM_3GPP_DRX_CYCLE_64, "MM_MODEM_3GPP_DRX_CYCLE_64", "64" },
    { MM_MODEM_3GPP_DRX_CYCLE_128, "MM_MODEM_3GPP_DRX_CYCLE_128", "128" },
    { MM_MODEM_3GPP_DRX_CYCLE_256, "MM_MODEM_3GPP_DRX_CYCLE_256", "256" },
    { 0, NULL, NULL }
};

GType
mm_modem_3gpp_drx_cycle_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMModem3gppDrxCycle"),
                                      mm_modem_3gpp_drx_cycle_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_modem_3gpp_drx_cycle_get_string (MMModem3gppDrxCycle val)
{
    guint i;

    for (i = 0; mm_modem_3gpp_drx_cycle_values[i].value_nick; i++) {
        if ((gint)val == mm_modem_3gpp_drx_cycle_values[i].value)
            return mm_modem_3gpp_drx_cycle_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_bearer_access_type_preference_values[] = {
    { MM_BEARER_ACCESS_TYPE_PREFERENCE_NONE, "MM_BEARER_ACCESS_TYPE_PREFERENCE_NONE", "none" },
    { MM_BEARER_ACCESS_TYPE_PREFERENCE_3GPP_ONLY, "MM_BEARER_ACCESS_TYPE_PREFERENCE_3GPP_ONLY", "3gpp-only" },
    { MM_BEARER_ACCESS_TYPE_PREFERENCE_3GPP_PREFERRED, "MM_BEARER_ACCESS_TYPE_PREFERENCE_3GPP_PREFERRED", "3gpp-preferred" },
    { MM_BEARER_ACCESS_TYPE_PREFERENCE_NON_3GPP_ONLY, "MM_BEARER_ACCESS_TYPE_PREFERENCE_NON_3GPP_ONLY", "non-3gpp-only" },
    { 0, NULL, NULL }
};

GType
mm_bearer_access_type_preference_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMBearerAccessTypePreference"),
                                      mm_bearer_access_type_preference_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_bearer_access_type_preference_get_string (MMBearerAccessTypePreference val)
{
    guint i;

    for (i = 0; mm_bearer_access_type_preference_values[i].value_nick; i++) {
        if ((gint)val == mm_bearer_access_type_preference_values[i].value)
            return mm_bearer_access_type_preference_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_bearer_profile_source_values[] = {
    { MM_BEARER_PROFILE_SOURCE_UNKNOWN, "MM_BEARER_PROFILE_SOURCE_UNKNOWN", "unknown" },
    { MM_BEARER_PROFILE_SOURCE_ADMIN, "MM_BEARER_PROFILE_SOURCE_ADMIN", "admin" },
    { MM_BEARER_PROFILE_SOURCE_USER, "MM_BEARER_PROFILE_SOURCE_USER", "user" },
    { MM_BEARER_PROFILE_SOURCE_OPERATOR, "MM_BEARER_PROFILE_SOURCE_OPERATOR", "operator" },
    { MM_BEARER_PROFILE_SOURCE_MODEM, "MM_BEARER_PROFILE_SOURCE_MODEM", "modem" },
    { MM_BEARER_PROFILE_SOURCE_DEVICE, "MM_BEARER_PROFILE_SOURCE_DEVICE", "device" },
    { 0, NULL, NULL }
};

GType
mm_bearer_profile_source_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMBearerProfileSource"),
                                      mm_bearer_profile_source_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_bearer_profile_source_get_string (MMBearerProfileSource val)
{
    guint i;

    for (i = 0; mm_bearer_profile_source_values[i].value_nick; i++) {
        if ((gint)val == mm_bearer_profile_source_values[i].value)
            return mm_bearer_profile_source_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_serving_cell_type_values[] = {
    { MM_SERVING_CELL_TYPE_UNKNOWN, "MM_SERVING_CELL_TYPE_UNKNOWN", "unknown" },
    { MM_SERVING_CELL_TYPE_PCELL, "MM_SERVING_CELL_TYPE_PCELL", "pcell" },
    { MM_SERVING_CELL_TYPE_SCELL, "MM_SERVING_CELL_TYPE_SCELL", "scell" },
    { MM_SERVING_CELL_TYPE_PSCELL, "MM_SERVING_CELL_TYPE_PSCELL", "pscell" },
    { MM_SERVING_CELL_TYPE_SSCELL, "MM_SERVING_CELL_TYPE_SSCELL", "sscell" },
    { MM_SERVING_CELL_TYPE_INVALID, "MM_SERVING_CELL_TYPE_INVALID", "invalid" },
    { 0, NULL, NULL }
};

GType
mm_serving_cell_type_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMServingCellType"),
                                      mm_serving_cell_type_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_serving_cell_type_get_string (MMServingCellType val)
{
    guint i;

    for (i = 0; mm_serving_cell_type_values[i].value_nick; i++) {
        if ((gint)val == mm_serving_cell_type_values[i].value)
            return mm_serving_cell_type_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mm_network_error_values[] = {
    { MM_NETWORK_ERROR_NONE, "MM_NETWORK_ERROR_NONE", "none" },
    { MM_NETWORK_ERROR_IMSI_UNKNOWN_IN_HLR, "MM_NETWORK_ERROR_IMSI_UNKNOWN_IN_HLR", "imsi-unknown-in-hlr" },
    { MM_NETWORK_ERROR_ILLEGAL_MS, "MM_NETWORK_ERROR_ILLEGAL_MS", "illegal-ms" },
    { MM_NETWORK_ERROR_IMSI_UNKNOWN_IN_VLR, "MM_NETWORK_ERROR_IMSI_UNKNOWN_IN_VLR", "imsi-unknown-in-vlr" },
    { MM_NETWORK_ERROR_IMEI_NOT_ACCEPTED, "MM_NETWORK_ERROR_IMEI_NOT_ACCEPTED", "imei-not-accepted" },
    { MM_NETWORK_ERROR_ILLEGAL_ME, "MM_NETWORK_ERROR_ILLEGAL_ME", "illegal-me" },
    { MM_NETWORK_ERROR_GPRS_NOT_ALLOWED, "MM_NETWORK_ERROR_GPRS_NOT_ALLOWED", "gprs-not-allowed" },
    { MM_NETWORK_ERROR_GPRS_AND_NON_GPRS_NOT_ALLOWED, "MM_NETWORK_ERROR_GPRS_AND_NON_GPRS_NOT_ALLOWED", "gprs-and-non-gprs-not-allowed" },
    { MM_NETWORK_ERROR_MS_IDENTITY_NOT_DERIVED_BY_NETWORK, "MM_NETWORK_ERROR_MS_IDENTITY_NOT_DERIVED_BY_NETWORK", "ms-identity-not-derived-by-network" },
    { MM_NETWORK_ERROR_IMPLICITLY_DETACHED, "MM_NETWORK_ERROR_IMPLICITLY_DETACHED", "implicitly-detached" },
    { MM_NETWORK_ERROR_PLMN_NOT_ALLOWED, "MM_NETWORK_ERROR_PLMN_NOT_ALLOWED", "plmn-not-allowed" },
    { MM_NETWORK_ERROR_LOCATION_AREA_NOT_ALLOWED, "MM_NETWORK_ERROR_LOCATION_AREA_NOT_ALLOWED", "location-area-not-allowed" },
    { MM_NETWORK_ERROR_ROAMING_NOT_ALLOWED_IN_LOCATION_AREA, "MM_NETWORK_ERROR_ROAMING_NOT_ALLOWED_IN_LOCATION_AREA", "roaming-not-allowed-in-location-area" },
    { MM_NETWORK_ERROR_GPRS_NOT_ALLOWED_IN_PLMN, "MM_NETWORK_ERROR_GPRS_NOT_ALLOWED_IN_PLMN", "gprs-not-allowed-in-plmn" },
    { MM_NETWORK_ERROR_NO_CELLS_IN_LOCATION_AREA, "MM_NETWORK_ERROR_NO_CELLS_IN_LOCATION_AREA", "no-cells-in-location-area" },
    { MM_NETWORK_ERROR_MSC_TEMPORARILY_NOT_REACHABLE, "MM_NETWORK_ERROR_MSC_TEMPORARILY_NOT_REACHABLE", "msc-temporarily-not-reachable" },
    { MM_NETWORK_ERROR_NETWORK_FAILURE, "MM_NETWORK_ERROR_NETWORK_FAILURE", "network-failure" },
    { MM_NETWORK_ERROR_CS_DOMAIN_NOT_AVAILABLE, "MM_NETWORK_ERROR_CS_DOMAIN_NOT_AVAILABLE", "cs-domain-not-available" },
    { MM_NETWORK_ERROR_ESM_FAILURE, "MM_NETWORK_ERROR_ESM_FAILURE", "esm-failure" },
    { MM_NETWORK_ERROR_MAC_FAILURE, "MM_NETWORK_ERROR_MAC_FAILURE", "mac-failure" },
    { MM_NETWORK_ERROR_SYNCH_FAILURE, "MM_NETWORK_ERROR_SYNCH_FAILURE", "synch-failure" },
    { MM_NETWORK_ERROR_CONGESTION, "MM_NETWORK_ERROR_CONGESTION", "congestion" },
    { MM_NETWORK_ERROR_GSM_AUTHENTICATION_UNACCEPTABLE, "MM_NETWORK_ERROR_GSM_AUTHENTICATION_UNACCEPTABLE", "gsm-authentication-unacceptable" },
    { MM_NETWORK_ERROR_NOT_AUTHORIZED_FOR_CSG, "MM_NETWORK_ERROR_NOT_AUTHORIZED_FOR_CSG", "not-authorized-for-csg" },
    { MM_NETWORK_ERROR_INSUFFICIENT_RESOURCES, "MM_NETWORK_ERROR_INSUFFICIENT_RESOURCES", "insufficient-resources" },
    { MM_NETWORK_ERROR_MISSING_OR_UNKNOWN_APN, "MM_NETWORK_ERROR_MISSING_OR_UNKNOWN_APN", "missing-or-unknown-apn" },
    { MM_NETWORK_ERROR_UNKNOWN_PDP_ADDRESS_OR_TYPE, "MM_NETWORK_ERROR_UNKNOWN_PDP_ADDRESS_OR_TYPE", "unknown-pdp-address-or-type" },
    { MM_NETWORK_ERROR_USER_AUTHENTICATION_FAILED, "MM_NETWORK_ERROR_USER_AUTHENTICATION_FAILED", "user-authentication-failed" },
    { MM_NETWORK_ERROR_ACTIVATION_REJECTED_BY_GGSN_OR_GW, "MM_NETWORK_ERROR_ACTIVATION_REJECTED_BY_GGSN_OR_GW", "activation-rejected-by-ggsn-or-gw" },
    { MM_NETWORK_ERROR_REDIRECTION_TO_5GCN_REQUIRED, "MM_NETWORK_ERROR_REDIRECTION_TO_5GCN_REQUIRED", "redirection-to-5gcn-required" },
    { MM_NETWORK_ERROR_SERVICE_OPTION_NOT_SUPPORTED, "MM_NETWORK_ERROR_SERVICE_OPTION_NOT_SUPPORTED", "service-option-not-supported" },
    { MM_NETWORK_ERROR_REQUESTED_SERVICE_OPTION_NOT_SUBSCRIBED, "MM_NETWORK_ERROR_REQUESTED_SERVICE_OPTION_NOT_SUBSCRIBED", "requested-service-option-not-subscribed" },
    { MM_NETWORK_ERROR_SERVICE_OPTION_TEMPORARILY_OUT_OF_ORDER, "MM_NETWORK_ERROR_SERVICE_OPTION_TEMPORARILY_OUT_OF_ORDER", "service-option-temporarily-out-of-order" },
    { MM_NETWORK_ERROR_REQUESTED_SERVICE_OPTION_NOT_AUTHORIZED, "MM_NETWORK_ERROR_REQUESTED_SERVICE_OPTION_NOT_AUTHORIZED", "requested-service-option-not-authorized" },
    { MM_NETWORK_ERROR_CALL_CANNOT_BE_IDENTIFIED, "MM_NETWORK_ERROR_CALL_CANNOT_BE_IDENTIFIED", "call-cannot-be-identified" },
    { MM_NETWORK_ERROR_CS_SERVICE_TEMPORARILY_NOT_AVAILABLE, "MM_NETWORK_ERROR_CS_SERVICE_TEMPORARILY_NOT_AVAILABLE", "cs-service-temporarily-not-available" },
    { MM_NETWORK_ERROR_NO_PDP_CONTEXT_ACTIVATED, "MM_NETWORK_ERROR_NO_PDP_CONTEXT_ACTIVATED", "no-pdp-context-activated" },
    { MM_NETWORK_ERROR_SEMANTIC_ERROR_IN_THE_TFT_OPERATION, "MM_NETWORK_ERROR_SEMANTIC_ERROR_IN_THE_TFT_OPERATION", "semantic-error-in-the-tft-operation" },
    { MM_NETWORK_ERROR_SYNTACTICAL_ERROR_IN_THE_TFT_OPERATION, "MM_NETWORK_ERROR_SYNTACTICAL_ERROR_IN_THE_TFT_OPERATION", "syntactical-error-in-the-tft-operation" },
    { MM_NETWORK_ERROR_UNKNOWN_PDP_CONTEXT, "MM_NETWORK_ERROR_UNKNOWN_PDP_CONTEXT", "unknown-pdp-context" },
    { MM_NETWORK_ERROR_SEMANTIC_ERRORS_IN_PACKET_FILTER, "MM_NETWORK_ERROR_SEMANTIC_ERRORS_IN_PACKET_FILTER", "semantic-errors-in-packet-filter" },
    { MM_NETWORK_ERROR_SYNTACTICAL_ERRORS_IN_PACKET_FILTER, "MM_NETWORK_ERROR_SYNTACTICAL_ERRORS_IN_PACKET_FILTER", "syntactical-errors-in-packet-filter" },
    { MM_NETWORK_ERROR_PDP_CONTEXT_WITHOUT_TFT_ALREADY_ACTIVATED, "MM_NETWORK_ERROR_PDP_CONTEXT_WITHOUT_TFT_ALREADY_ACTIVATED", "pdp-context-without-tft-already-activated" },
    { MM_NETWORK_ERROR_REQUEST_REJECTED_OR_BEARER_CONTROL_MODE_VIOLATION, "MM_NETWORK_ERROR_REQUEST_REJECTED_OR_BEARER_CONTROL_MODE_VIOLATION", "request-rejected-or-bearer-control-mode-violation" },
    { MM_NETWORK_ERROR_LAST_PDN_DISCONNECTION_NOT_ALLOWED, "MM_NETWORK_ERROR_LAST_PDN_DISCONNECTION_NOT_ALLOWED", "last-pdn-disconnection-not-allowed" },
    { MM_NETWORK_ERROR_PDP_TYPE_IPV4_ONLY_ALLOWED, "MM_NETWORK_ERROR_PDP_TYPE_IPV4_ONLY_ALLOWED", "pdp-type-ipv4-only-allowed" },
    { MM_NETWORK_ERROR_PDP_TYPE_IPV6_ONLY_ALLOWED, "MM_NETWORK_ERROR_PDP_TYPE_IPV6_ONLY_ALLOWED", "pdp-type-ipv6-only-allowed" },
    { MM_NETWORK_ERROR_NO_NETWORK_SLICES_AVAILABLE, "MM_NETWORK_ERROR_NO_NETWORK_SLICES_AVAILABLE", "no-network-slices-available" },
    { MM_NETWORK_ERROR_MAXIMUM_NUMBER_OF_PDP_CONTEXTS_REACHED, "MM_NETWORK_ERROR_MAXIMUM_NUMBER_OF_PDP_CONTEXTS_REACHED", "maximum-number-of-pdp-contexts-reached" },
    { MM_NETWORK_ERROR_REQUESTED_APN_NOT_SUPPORTED_IN_CURRENT_RAT_AND_PLMN, "MM_NETWORK_ERROR_REQUESTED_APN_NOT_SUPPORTED_IN_CURRENT_RAT_AND_PLMN", "requested-apn-not-supported-in-current-rat-and-plmn" },
    { MM_NETWORK_ERROR_INSUFFICIENT_RESOURCES_FOR_SPECIFIC_SLICE_AND_DNN, "MM_NETWORK_ERROR_INSUFFICIENT_RESOURCES_FOR_SPECIFIC_SLICE_AND_DNN", "insufficient-resources-for-specific-slice-and-dnn" },
    { MM_NETWORK_ERROR_INSUFFICIENT_RESOURCES_FOR_SPECIFIC_SLICE, "MM_NETWORK_ERROR_INSUFFICIENT_RESOURCES_FOR_SPECIFIC_SLICE", "insufficient-resources-for-specific-slice" },
    { MM_NETWORK_ERROR_NGKSI_ALREADY_IN_USE, "MM_NETWORK_ERROR_NGKSI_ALREADY_IN_USE", "ngksi-already-in-use" },
    { MM_NETWORK_ERROR_NON_3GPP_ACCESS_TO_5GCN_NOT_ALLOWED, "MM_NETWORK_ERROR_NON_3GPP_ACCESS_TO_5GCN_NOT_ALLOWED", "non-3gpp-access-to-5gcn-not-allowed" },
    { MM_NETWORK_ERROR_SERVING_NETWORK_NOT_AUTHORIZED, "MM_NETWORK_ERROR_SERVING_NETWORK_NOT_AUTHORIZED", "serving-network-not-authorized" },
    { MM_NETWORK_ERROR_TEMPORARILY_NOT_AUTHORIZED_FOR_THIS_SNPN, "MM_NETWORK_ERROR_TEMPORARILY_NOT_AUTHORIZED_FOR_THIS_SNPN", "temporarily-not-authorized-for-this-snpn" },
    { MM_NETWORK_ERROR_PERMANENTLY_NOT_AUTHORIZED_FOR_THIS_SNPN, "MM_NETWORK_ERROR_PERMANENTLY_NOT_AUTHORIZED_FOR_THIS_SNPN", "permanently-not-authorized-for-this-snpn" },
    { MM_NETWORK_ERROR_NOT_AUTHORIZED_FOR_THIS_CAG_OR_AUTHORIZED_FOR_CAG_CELLS_ONLY, "MM_NETWORK_ERROR_NOT_AUTHORIZED_FOR_THIS_CAG_OR_AUTHORIZED_FOR_CAG_CELLS_ONLY", "not-authorized-for-this-cag-or-authorized-for-cag-cells-only" },
    { MM_NETWORK_ERROR_WIRELINE_ACCESS_AREA_NOT_ALLOWED, "MM_NETWORK_ERROR_WIRELINE_ACCESS_AREA_NOT_ALLOWED", "wireline-access-area-not-allowed" },
    { MM_NETWORK_ERROR_PAYLOAD_WAS_NOT_FORWARDED, "MM_NETWORK_ERROR_PAYLOAD_WAS_NOT_FORWARDED", "payload-was-not-forwarded" },
    { MM_NETWORK_ERROR_DNN_NOT_SUPPORTED_OR_NOT_SUBSCRIBED_IN_THE_SLICE, "MM_NETWORK_ERROR_DNN_NOT_SUPPORTED_OR_NOT_SUBSCRIBED_IN_THE_SLICE", "dnn-not-supported-or-not-subscribed-in-the-slice" },
    { MM_NETWORK_ERROR_INSUFFICIENT_USER_PLANE_RESOURCES_FOR_THE_PDU_SESSION, "MM_NETWORK_ERROR_INSUFFICIENT_USER_PLANE_RESOURCES_FOR_THE_PDU_SESSION", "insufficient-user-plane-resources-for-the-pdu-session" },
    { MM_NETWORK_ERROR_SEMANTICALLY_INCORRECT_MESSAGE, "MM_NETWORK_ERROR_SEMANTICALLY_INCORRECT_MESSAGE", "semantically-incorrect-message" },
    { MM_NETWORK_ERROR_INVALID_MANDATORY_INFORMATION, "MM_NETWORK_ERROR_INVALID_MANDATORY_INFORMATION", "invalid-mandatory-information" },
    { MM_NETWORK_ERROR_MESSAGE_TYPE_NON_EXISTENT_OR_NOT_IMPLEMENTED, "MM_NETWORK_ERROR_MESSAGE_TYPE_NON_EXISTENT_OR_NOT_IMPLEMENTED", "message-type-non-existent-or-not-implemented" },
    { MM_NETWORK_ERROR_MESSAGE_TYPE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE, "MM_NETWORK_ERROR_MESSAGE_TYPE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE", "message-type-not-compatible-with-protocol-state" },
    { MM_NETWORK_ERROR_INFORMATION_ELEMENT_NON_EXISTENT_OR_NOT_IMPLEMENTED, "MM_NETWORK_ERROR_INFORMATION_ELEMENT_NON_EXISTENT_OR_NOT_IMPLEMENTED", "information-element-non-existent-or-not-implemented" },
    { MM_NETWORK_ERROR_CONDITIONAL_IE_ERROR, "MM_NETWORK_ERROR_CONDITIONAL_IE_ERROR", "conditional-ie-error" },
    { MM_NETWORK_ERROR_MESSAGE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE, "MM_NETWORK_ERROR_MESSAGE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE", "message-not-compatible-with-protocol-state" },
    { MM_NETWORK_ERROR_PROTOCOL_ERROR_UNSPECIFIED, "MM_NETWORK_ERROR_PROTOCOL_ERROR_UNSPECIFIED", "protocol-error-unspecified" },
    { MM_NETWORK_ERROR_APN_RESTRICTION_VALUE_INCOMPATIBLE_WITH_ACTIVE_PDP_CONTEXT, "MM_NETWORK_ERROR_APN_RESTRICTION_VALUE_INCOMPATIBLE_WITH_ACTIVE_PDP_CONTEXT", "apn-restriction-value-incompatible-with-active-pdp-context" },
    { MM_NETWORK_ERROR_MULTIPLE_ACCESSES_TO_A_PDN_CONNECTION_NOT_ALLOWED, "MM_NETWORK_ERROR_MULTIPLE_ACCESSES_TO_A_PDN_CONNECTION_NOT_ALLOWED", "multiple-accesses-to-a-pdn-connection-not-allowed" },
    { MM_NETWORK_ERROR_UNKNOWN, "MM_NETWORK_ERROR_UNKNOWN", "unknown" },
    { 0, NULL, NULL }
};

GType
mm_network_error_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MMNetworkError"),
                                      mm_network_error_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

const gchar *
mm_network_error_get_string (MMNetworkError val)
{
    guint i;

    for (i = 0; mm_network_error_values[i].value_nick; i++) {
        if ((gint)val == mm_network_error_values[i].value)
            return mm_network_error_values[i].value_nick;
    }

    return NULL;
}

/* Generated data ends here */

